import logging

from django.core.management import BaseCommand
from django.db import transaction, connection, IntegrityError
from tqdm import tqdm

logger = logging.getLogger(__name__)


class Command(BaseCommand):
    help = "Тестирование"

    def handle(self, *args, **options):
        logger.info(self.help)

        with connection.cursor() as cursor:
            cursor.execute(f'''with a as (
                                select trim(value_str), attr_type_id, att.code, count(*)
                                from kd_document_attributes
                                join ckk_attr_type att on att.id = kd_document_attributes.attr_type_id
                                where value_str is not null
                                group by delete_dbl_spaces(value_str), attr_type_id, att.code
                                having count(*) > 1
                            )
                            
                            select count(*)
                            from a''')
            qty, = cursor.fetchone()
            pbar = tqdm(total=qty)
            deleted_cnt = 0
            not_deleted_cnt = 0

            # with transaction.atomic():
            cursor.execute(f'''with a as (
                                            select trim(value_str), attr_type_id, att.code, count(*)
                                            from kd_document_attributes
                                            join ckk_attr_type att on att.id = kd_document_attributes.attr_type_id
                                            where value_str is not null
                                            group by delete_dbl_spaces(value_str), attr_type_id, att.code
                                            having count(*) > 1
                                        )

                                        select *
                                        from a''')

            rows = cursor.fetchall()

            for row in rows:
                value_str, attr_type_id, code, count = row

                cursor.execute(f'''select id
                                    from kd_document_attributes
                                    where trim(value_str) = %s
                                      and attr_type_id = %s
                                    order by id''', [value_str.strip(), attr_type_id])
                rows1 = cursor.fetchall()
                for row1 in rows1:
                    id, = row1
                    try:
                        cursor.execute(f'''delete from kd_document_attributes where id=%s''', [id])
                        deleted_cnt += 1
                    except IntegrityError:
                        not_deleted_cnt += 1
                    # if step_first:
                    #     step_first = False
                    #     id_main = id
                    # else:
                    #     # res = Item.objects.filter(STMP_1_id=id).update(STMP_1=id_main)
                    #     # res = Item.objects.filter(STMP_2_id=id).update(STMP_2=id_main)
                    #     # res = Document_attr_cross.objects.filter(attribute_id=id).update(attribute_id=id_main)
                    #     cursor.execute(f'''delete from kd_document_attributes where id=%s''', [id])
                if pbar:
                    pbar.update(1)

        if pbar:
            pbar.close()
            print(f'Deleted: {deleted_cnt}')
            print(f'Not Deleted: {not_deleted_cnt}')



from django.urls import path

from kaf_pas.planing.views import operation_material

urlpatterns = [

    path('Operation_material/Fetch/', operation_material.Operation_material_Fetch),
    path('Operation_material/Add', operation_material.Operation_material_Add),
    path('Operation_material/Update', operation_material.Operation_material_Update),
    path('Operation_material/Remove', operation_material.Operation_material_Remove),
    path('Operation_material/Lookup/', operation_material.Operation_material_Lookup),
    path('Operation_material/Info/', operation_material.Operation_material_Info),
    path('Operation_material/Copy', operation_material.Operation_material_Copy),

]



# Generated by Django 2.2.3 on 2019-07-07 20:35

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0127_materials_nomenklatura_1c'),
    ]

    operations = [
        migrations.RenameField(
            model_name='materials',
            old_name='nomenklatura_1C',
            new_name='nomenklatura_model',
        ),
    ]



import logging

from django.core.management import BaseCommand
from django.db import transaction

from isc_common.logger.Logger import Logger

logger = logging.getLogger(__name__)
logger.__class__ = Logger


class Command(BaseCommand):
    help = 'Создание товаоных позиций после импорта из Лоцмана'

    def handle(self, *args, **options):
        try:
            from kaf_pas.kd.models.documents_thumb import Documents_thumbManager
            with transaction.atomic():
                Documents_thumbManager.refreshFromDbls(doc_type='lotsman_document', table_name='thumb')
                Documents_thumbManager.refreshFromDbls(doc_type='lotsman_document', table_name='thumb10')

                Documents_thumbManager.refreshFromDbls(doc_type='document', table_name='thumb')
                Documents_thumbManager.refreshFromDbls(doc_type='document', table_name='thumb10')
        except Exception as ex:
            raise ex



# Generated by Django 2.2.2 on 2019-06-08 13:41

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0037_document_attrs_view'),
        ('ckk', '0083_auto_20190607_1923'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='item',
            unique_together={('STMP_1', 'STMP_2', 'props')},
        ),
    ]



# Generated by Django 2.2.7 on 2019-11-18 11:30

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0158_delete_status'),
        ('production', '0104_auto_20191118_1127'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='launch_operations_item',
            unique_together={('item', 'num', 'launch')},
        ),
    ]



import logging

from bitfield import BitField

from isc_common.fields.name_field import NameStrictField
from isc_common.managers.common_managet_with_lookup_fields import CommonManagetWithLookUpFieldsManager, CommonManagetWithLookUpFieldsQuerySet
from isc_common.models.base_ref import BaseRefHierarcy, BaseRefQuerySet
from isc_common.number import DelProps

logger = logging.getLogger(__name__)


class OperationsQuerySet(CommonManagetWithLookUpFieldsQuerySet, BaseRefQuerySet):
    pass


class OperationsManager(CommonManagetWithLookUpFieldsManager):

    @staticmethod
    def getRecord(record):
        res = {
            'id': record.id,
            'code': record.code,
            'name': record.name,
            'full_name': record.full_name,
            'description': record.description,
            'parent_id': record.parent_id,
            'lastmodified': record.lastmodified,
            'editing': record.editing,
            'deliting': record.deliting,
            'props': record.props,
            'assemly': record.props.assemly,
            'made_common_form': record.props.made_common_form,
        }
        return DelProps(res)

    def get_queryset(self):
        return OperationsQuerySet(self.model, using=self._db)

    @staticmethod
    def get_props():
        return BitField(flags=(
            ('assemly', 'Операция комплектации'),  # 1
            ('made_common_form', 'Формировать общий документ'),  # 1
        ), default=0, db_index=True)


class Operations(BaseRefHierarcy):
    name = NameStrictField()
    props = OperationsManager.get_props()

    @property
    def attrs(self):
        from kaf_pas.production.models.operation_attr import Operation_attr
        return [item.attr_type.code for item in Operation_attr.objects.filter(operation=self)]

    objects = OperationsManager()

    def __str__(self):
        return f'ID={self.id}, code={self.code}, name={self.name}, description={self.description}'

    class Meta:
        verbose_name = 'Операции'



# Generated by Django 3.0.2 on 2020-01-19 17:44

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0185_auto_20200117_1305'),
        ('accounting', '0004_tmp_buffer_edizm'),
    ]

    operations = [
        migrations.AlterField(
            model_name='tmp_buffer',
            name='edizm',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='ckk.Ed_izm'),
        ),
    ]



# Generated by Django 3.0.2 on 2020-01-17 16:00

import bitfield.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0164_auto_20191225_1105'),
    ]

    operations = [
        migrations.AlterField(
            model_name='launches',
            name='props',
            field=bitfield.models.BitField((('routing_made', 'Маршрутизация выполнена'),), db_index=True, default=0),
        ),
    ]



# Generated by Django 2.2.6 on 2019-10-08 13:07

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0070_auto_20191008_1258'),
    ]

    operations = [
        migrations.RenameField(
            model_name='operation_material',
            old_name='operation_item',
            new_name='operationitem',
        ),
        migrations.RenameField(
            model_name='operation_resources',
            old_name='operation_item',
            new_name='operationitem',
        ),
    ]



# Generated by Django 2.2.8 on 2019-12-02 12:54

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0122_auto_20191128_1229'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='tec_spc_item_refs',
            unique_together=None,
        ),
        migrations.RemoveField(
            model_name='tec_spc_item_refs',
            name='child',
        ),
        migrations.RemoveField(
            model_name='tec_spc_item_refs',
            name='item_refs',
        ),
        migrations.RemoveField(
            model_name='tec_spc_item_refs',
            name='parent',
        ),
        migrations.DeleteModel(
            name='Tec_spc_item_line',
        ),
        migrations.DeleteModel(
            name='Tec_spc_item_refs',
        ),
    ]



# Generated by Django 2.2.7 on 2019-11-19 08:57

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0113_auto_20191119_0726'),
    ]

    operations = [
        migrations.AddField(
            model_name='operation_material',
            name='parent',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='production.Operation_material'),
        ),
    ]



# Generated by Django 2.2.3 on 2019-07-10 11:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0056_uploades_log'),
    ]

    operations = [
        migrations.AddField(
            model_name='pathes',
            name='prefix',
            field=models.CharField(blank=True, max_length=10, null=True, verbose_name='Префикс к полному пути'),
        ),
    ]



import logging

from isc_common import setAttr

from kaf_pas.kd.models.document_attributes import Document_attributesQuerySet
from kaf_pas.kd.models.document_attributes_view import Document_attributes_view, Document_attributes_viewManager

logger = logging.getLogger(__name__)


class Cdw_attrsQuerySet(Document_attributesQuerySet):

    def filter(self, *args, **kwargs):
        setAttr(kwargs, 'attr_type__code__contains', 'STMP')
        return super().filter(*args, **kwargs)


class Cdw_attrsManager(Document_attributes_viewManager):

    def get_queryset(self):
        return Cdw_attrsQuerySet(self.model, using=self._db)

    @staticmethod
    def getRecord(record):
        res = {
            "id": record.id,
            "attr_type_id": record.attr_type.id,
            "attr_type__code": record.attr_type.code,
            "attr_type__name": record.attr_type.name,
            "attr_type__description": record.attr_type.description if record.attr_type else None,
            "section": record.section,
            "subsection": record.subsection,
            "value_str": record.value_str,
            "lastmodified": record.lastmodified,
            "editing": record.editing,
            "deliting": record.deliting,
        }
        return res


class Cdw_attrs(Document_attributes_view):
    objects = Cdw_attrsManager()

    class Meta:
        verbose_name = 'Чертеж'
        proxy = True
        managed = False



# Generated by Django 2.2.8 on 2019-12-08 10:01

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0052_auto_20191208_0959'),
    ]

    operations = [
        migrations.AlterField(
            model_name='operation_refs',
            name='outcome',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, related_name='operation_outcome', to='planing.Operations'),
        ),
    ]



import logging
import sys
from datetime import datetime

from django.conf import settings
from django.db import transaction
from django.db.models import Sum
from django.forms import model_to_dict

from isc_common.http.DSRequest import DSRequest
from isc_common.number import DelProps
from kaf_pas.planing.models.operations import OperationsManager, OperationsQuerySet
from kaf_pas.planing.models.operations_view import Operations_view

logger = logging.getLogger(__name__)


class Production_orderQuerySet(OperationsQuerySet):
    def get_checkStatus(self, request, *args):
        from kaf_pas.planing.models.operations import Operations
        from kaf_pas.planing.models.status_operation_types import Status_operation_types

        request = DSRequest(request=request)
        data = request.json.get('data')
        status__code = data.get('status__code')
        status__name = data.get('status__name')
        id = data.get('id')
        if status__code == 'in_job':
            return dict(status__code=status__code, status__name=status__name, input='closed')
        else:
            operation = Operations.objects.get(id=id)
            operation.prev_status = operation.status
            operation.status = Status_operation_types.objects.get(code='in_job')
            operation.save()
            return dict(status__code=operation.status.code, status__name=operation.status.wrap_name, input='opened')

    def get_setPrevStatus(self, request, *args):
        from kaf_pas.planing.models.operations import Operations

        request = DSRequest(request=request)
        data = request.json.get('data')
        status__code = data.get('status__code')

        if status__code in ["started", "started_partly"]:
            operation = Operations.objects.get(id=id)
            return dict(status__code=operation.status.code, status__name=operation.status.wrap_name, input='opened')

        id = data.get('id')
        if status__code == 'in_job':
            operation = Operations.objects.get(id=id)
            operation.status = operation.prev_status
            operation.save()
            return dict(status__code=operation.status.code, status__name=operation.status.wrap_name, input='opened')

    def _checkEnableQty(self, data):
        qty = data.get('qty')
        if data.get('qty') == None:
            raise Exception('Не введено количество.')
        production_order = Production_order.objects.get(id=data.get('id'))
        value_made = production_order.value_made
        if qty < value_made:
            raise Exception('Превышение существующего количества выпуска.')

    def get_setStartStatus(self, request, *args):
        from kaf_pas.planing.models.operation_refs import Operation_refs
        from kaf_pas.planing.models.operation_value import Operation_value
        from kaf_pas.planing.models.operations import Operations

        request = DSRequest(request=request)
        data = request.json.get('data')

        self._checkEnableQty(data)
        with transaction.atomic():
            try:
                res = Operation_refs.objects.get(parent_id=data.get('id'), child__opertype__code='LAUNCH_TSK')
                Operation_value.objects.update_or_create(operation=res.child, defaults=dict(value=data.get('qty')))
                res = model_to_dict(res.parent)
                data.update(res)
                return data
            except Operation_refs.DoesNotExist:
                res = Operations.objects.create(
                    opertype=settings.OPERS_TYPES_STACK.LAUNCH_TASK,
                    date=datetime.now(),
                    status=settings.OPERS_TYPES_STACK.LAUNCH_TASK_STATUSES.get('new'),
                    creator=request.user
                )

                Operation_refs.objects.create(parent_id=data.get('id'), child=res)
                Operation_value.objects.create(operation=res, edizm_id=data.get('edizm_id'), value=data.get('qty'))
                res = model_to_dict(res)
                data.update(res)
                return data

    def getValue_made(self, request, *args):
        request = DSRequest(request=request)
        data = request.json.get('data')
        production_order = Production_order.objects.get(id=data.get('id'))
        res = production_order.value_made
        return dict(value_made=res)


class Production_orderManager(OperationsManager):
    @staticmethod
    def getRecord(record):
        status = record.get_status
        res = {
            'id': record.id,
            'num': record.num,
            'date': record.date,
            'status__code': status.code,
            'status__name': status.wrap_name,
            'prev_status__code': record.prev_status.code if record.prev_status else None,
            'prev_status__name': record.prev_status.wrap_name if record.prev_status else None,
            'status_id': record.status.id if record.status else None,
            'item__STMP_1__value_str': record.item.STMP_1.value_str if record.item and record.item.STMP_1 and record.item.STMP_1 else None,
            'item__STMP_1_id': record.item.STMP_1.id if record.item and record.item.STMP_1 and record.item.STMP_1 else None,
            'item__STMP_2__value_str': record.item.STMP_2.value_str if record.item and record.item.STMP_2 and record.item.STMP_2 else None,
            'item__STMP_2_id': record.item.STMP_2.id if record.item and record.item.STMP_2 and record.item.STMP_2 else None,
            'item_full_name': record.item_full_name,
            'item_id': record.item.id if record.item else None,
            'item_item_name': record.item.item_name if record.item else None,
            'value': record.value.value if record.value else None,
            'value_start': record.value_start,
            'value_made': record.value_made,
            'creator__short_name': record.creator.get_short_name,
            'launch_id': record.launch.id if record.launch else None,
            'launch__date': record.launch.date if record.launch else None,
            'launch__code': record.launch.code if record.launch else None,
            'launch__name': record.launch.name if record.launch else None,
            'edizm__code': record.value.edizm.code if record.value and record.value.edizm else None,
            'edizm__name': record.value.edizm.name if record.value and record.value.edizm else None,
            'edizm_id': record.value.edizm.id if record.value and record.value.edizm else None,
            'creator_id': record.creator.id,
            'description': record.description,
            'isFolder': False,
        }
        return DelProps(res)

    @staticmethod
    def get_resource_workshop(location_id):
        from kaf_pas.ckk.models.locations import Locations

        res = None
        for location in Locations.objects_tree.get_parents(id=location_id, child_id='id', include_self=False):
            if location.props.isWorkshop == True:
                res = dict(id=location.id, title=location.name, prompt=location.full_name)
                break

        if res == None:
            raise Exception(f'Не обнаружен цех, с признаком "Уровень цеха" для : {Locations.objects.get(id=location_id).full_name}')
        return res

    @staticmethod
    def getRecordLocations(record):
        return Production_orderManager.get_resource_workshop(record.get('resource__location_id'))

    @staticmethod
    def getRecordLevels(record):
        return dict(id=record.get('operation_level_id'), title=record.get('operation_level__name'))

    def get_queryset(self):
        return Production_orderQuerySet(self.model, using=self._db)


class Production_order(Operations_view):
    from kaf_pas.planing.models.status_operation_types import Status_operation_types

    objects = Production_orderManager()

    try:
        not_ready_2_start = Status_operation_types.objects.get(code='not_ready_2_start')
        ready_2_start = Status_operation_types.objects.get(code='ready_2_start')
        started_partly = Status_operation_types.objects.get(code='started_partly')
        started = Status_operation_types.objects.get(code='started')
    except Exception as ex:
        logger.error(ex)

    @property
    def get_status(self):
        from kaf_pas.accounting.models.buffers import BuffersManager
        from kaf_pas.production.models.launch_item_refs import Launch_item_refs
        from kaf_pas.planing.models.status_operation_types import Status_operation_types
        from kaf_pas.planing.models.operations import Operations

        status = self.status

        def get_ready_status(enabled_start_qty):
            return Status_operation_types.objects.get_or_create(
                code=f'ready_2_start_{enabled_start_qty}',
                defaults=dict(
                    name=f'Готов к запуску: ({enabled_start_qty})',
                    color='green',
                    prop=Status_operation_types.props.blink
                ))

        enabled_start_qty = sys.maxsize
        value_start = self.value_start

        full_start = True

        for launch_item_refs in Launch_item_refs.objects.filter(launch_id=self.launch.id, parent=self.item.id):
            qty_exists = BuffersManager.getValue(item=launch_item_refs.child)
            if qty_exists == None:
                operation = Operations.objects.get(id=self.id)
                operation.status = self.not_ready_2_start
                operation.save()
                return self.not_ready_2_start
            else:
                if qty_exists >= launch_item_refs.qty_per_one * value_start:
                    enabled_start_qty = launch_item_refs.qty_per_one * value_start
                else:
                    full_start = False
                    en = qty_exists // launch_item_refs.qty_per_one
                    if en < enabled_start_qty:
                        enabled_start_qty = en

        operation = Operations.objects.get(id=self.id)
        if enabled_start_qty == sys.maxsize or full_start == True:
            if value_start == 0:
                operation.status = self.ready_2_start
            elif value_start >= self.value.value:
                operation.status = self.started
            elif value_start < self.value.value:
                operation.status = self.started_partly
            else:
                operation.status = self.ready_2_start
        else:
            operation.status = get_ready_status(enabled_start_qty=enabled_start_qty)
        operation.save()
        return operation.status

    @property
    def value_made(self):
        from kaf_pas.planing.models.operation_refs import Operation_refs
        from kaf_pas.planing.models.operation_value import Operation_value

        operations = [child.child_id for child in Operation_refs.objects.filter(parent_id=self.id, child__opertype=settings.OPERS_TYPES_STACK.RELEASE_TASK_PLUS)]
        res = Operation_value.objects.filter(operation_id__in=operations).aggregate(Sum('value'))
        sum = res.get('value__sum')
        return sum if sum != None else 0

    @property
    def value_start(self):
        from kaf_pas.planing.models.operations import Operations
        return Operations.objects.get(id=self.id).value_start

    def __str__(self):
        return super().__str__()

    def __repr__(self):
        return self.__str__()

    class Meta:
        proxy = True
        verbose_name = 'Заказы на производство'



# Generated by Django 2.2.1 on 2019-06-05 10:35

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0048_auto_20190605_1031'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='operations_type',
            name='parent',
        ),
        migrations.RemoveField(
            model_name='operations',
            name='category',
        ),
        migrations.RemoveField(
            model_name='operations',
            name='type',
        ),
        migrations.DeleteModel(
            name='Operation_categories',
        ),
        migrations.DeleteModel(
            name='Operations_type',
        ),
    ]



# Generated by Django 3.0.3 on 2020-02-08 16:09

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0204_auto_20200208_1413'),
    ]

    operations = [
        migrations.RemoveConstraint(
            model_name='item',
            name='Item_unique_constraint_0',
        ),
        migrations.RemoveConstraint(
            model_name='item',
            name='Item_unique_constraint_1',
        ),
        migrations.RemoveConstraint(
            model_name='item',
            name='Item_unique_constraint_2',
        ),
        migrations.RemoveConstraint(
            model_name='item',
            name='Item_unique_constraint_3',
        ),
        migrations.RemoveConstraint(
            model_name='item',
            name='Item_unique_constraint_4',
        ),
        migrations.RemoveConstraint(
            model_name='item',
            name='Item_unique_constraint_5',
        ),
        migrations.RemoveConstraint(
            model_name='item',
            name='Item_unique_constraint_6',
        ),
        migrations.RemoveConstraint(
            model_name='item',
            name='Item_unique_constraint_7',
        ),
        migrations.RemoveConstraint(
            model_name='item',
            name='Item_unique_constraint_8',
        ),
        migrations.RemoveConstraint(
            model_name='item',
            name='Item_unique_constraint_9',
        ),
        migrations.RemoveConstraint(
            model_name='item',
            name='Item_unique_constraint_10',
        ),
        migrations.RemoveConstraint(
            model_name='item',
            name='Item_unique_constraint_11',
        ),
        migrations.RemoveConstraint(
            model_name='item',
            name='Item_unique_constraint_12',
        ),
        migrations.RemoveConstraint(
            model_name='item',
            name='Item_unique_constraint_13',
        ),
        migrations.RemoveConstraint(
            model_name='item',
            name='Item_unique_constraint_14',
        ),
        migrations.RemoveConstraint(
            model_name='item',
            name='Item_unique_constraint_15',
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_1', None), ('STMP_2', None), ('lotsman_document_id', None), ('lotsman_type_id', None), ('version', None)), fields=('props',), name='Item_unique_constraint_0'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_2', None), ('lotsman_document_id', None), ('lotsman_type_id', None), ('version', None)), fields=('STMP_1', 'props'), name='Item_unique_constraint_1'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_1', None), ('lotsman_document_id', None), ('lotsman_type_id', None), ('version', None)), fields=('STMP_2', 'props'), name='Item_unique_constraint_2'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('lotsman_document_id', None), ('lotsman_type_id', None), ('version', None)), fields=('STMP_1', 'STMP_2', 'props'), name='Item_unique_constraint_3'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_1', None), ('STMP_2', None), ('lotsman_document_id', None), ('lotsman_type_id', None)), fields=('props', 'version'), name='Item_unique_constraint_4'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_2', None), ('lotsman_document_id', None), ('lotsman_type_id', None)), fields=('STMP_1', 'props', 'version'), name='Item_unique_constraint_5'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_1', None), ('lotsman_document_id', None), ('lotsman_type_id', None)), fields=('STMP_2', 'props', 'version'), name='Item_unique_constraint_6'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('lotsman_document_id', None), ('lotsman_type_id', None)), fields=('STMP_1', 'STMP_2', 'props', 'version'), name='Item_unique_constraint_7'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_1', None), ('STMP_2', None), ('lotsman_type_id', None), ('version', None)), fields=('lotsman_document_id', 'props'), name='Item_unique_constraint_8'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_2', None), ('lotsman_type_id', None), ('version', None)), fields=('STMP_1', 'lotsman_document_id', 'props'), name='Item_unique_constraint_9'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_1', None), ('lotsman_type_id', None), ('version', None)), fields=('STMP_2', 'lotsman_document_id', 'props'), name='Item_unique_constraint_10'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('lotsman_type_id', None), ('version', None)), fields=('STMP_1', 'STMP_2', 'lotsman_document_id', 'props'), name='Item_unique_constraint_11'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_1', None), ('STMP_2', None), ('lotsman_type_id', None)), fields=('lotsman_document_id', 'props', 'version'), name='Item_unique_constraint_12'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_2', None), ('lotsman_type_id', None)), fields=('STMP_1', 'lotsman_document_id', 'props', 'version'), name='Item_unique_constraint_13'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_1', None), ('lotsman_type_id', None)), fields=('STMP_2', 'lotsman_document_id', 'props', 'version'), name='Item_unique_constraint_14'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(lotsman_type_id=None), fields=('STMP_1', 'STMP_2', 'lotsman_document_id', 'props', 'version'), name='Item_unique_constraint_15'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_1', None), ('STMP_2', None), ('lotsman_document_id', None), ('version', None)), fields=('lotsman_type_id', 'props'), name='Item_unique_constraint_16'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_2', None), ('lotsman_document_id', None), ('version', None)), fields=('STMP_1', 'lotsman_type_id', 'props'), name='Item_unique_constraint_17'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_1', None), ('lotsman_document_id', None), ('version', None)), fields=('STMP_2', 'lotsman_type_id', 'props'), name='Item_unique_constraint_18'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('lotsman_document_id', None), ('version', None)), fields=('STMP_1', 'STMP_2', 'lotsman_type_id', 'props'), name='Item_unique_constraint_19'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_1', None), ('STMP_2', None), ('lotsman_document_id', None)), fields=('lotsman_type_id', 'props', 'version'), name='Item_unique_constraint_20'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_2', None), ('lotsman_document_id', None)), fields=('STMP_1', 'lotsman_type_id', 'props', 'version'), name='Item_unique_constraint_21'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_1', None), ('lotsman_document_id', None)), fields=('STMP_2', 'lotsman_type_id', 'props', 'version'), name='Item_unique_constraint_22'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(lotsman_document_id=None), fields=('STMP_1', 'STMP_2', 'lotsman_type_id', 'props', 'version'), name='Item_unique_constraint_23'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_1', None), ('STMP_2', None), ('version', None)), fields=('lotsman_document_id', 'lotsman_type_id', 'props'), name='Item_unique_constraint_24'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_2', None), ('version', None)), fields=('STMP_1', 'lotsman_document_id', 'lotsman_type_id', 'props'), name='Item_unique_constraint_25'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_1', None), ('version', None)), fields=('STMP_2', 'lotsman_document_id', 'lotsman_type_id', 'props'), name='Item_unique_constraint_26'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(version=None), fields=('STMP_1', 'STMP_2', 'lotsman_document_id', 'lotsman_type_id', 'props'), name='Item_unique_constraint_27'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(('STMP_1', None), ('STMP_2', None)), fields=('lotsman_document_id', 'lotsman_type_id', 'props', 'version'), name='Item_unique_constraint_28'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(STMP_2=None), fields=('STMP_1', 'lotsman_document_id', 'lotsman_type_id', 'props', 'version'), name='Item_unique_constraint_29'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(condition=models.Q(STMP_1=None), fields=('STMP_2', 'lotsman_document_id', 'lotsman_type_id', 'props', 'version'), name='Item_unique_constraint_30'),
        ),
        migrations.AddConstraint(
            model_name='item',
            constraint=models.UniqueConstraint(fields=('STMP_1', 'STMP_2', 'lotsman_document_id', 'lotsman_type_id', 'props', 'version'), name='Item_unique_constraint_31'),
        ),
    ]



# Generated by Django 2.2.3 on 2019-07-19 06:00

import bitfield.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0063_auto_20190715_0842'),
    ]

    operations = [
        migrations.AddField(
            model_name='documents_thumb',
            name='props',
            field=bitfield.models.BitField((('relevant', 'Актуальность'),), db_index=True, default=1),
        ),
        migrations.AddField(
            model_name='documents_thumb10',
            name='props',
            field=bitfield.models.BitField((('relevant', 'Актуальность'),), db_index=True, default=1),
        ),
        migrations.AlterModelTable(
            name='documents_view',
            table='kd_documents_mview',
        ),
    ]



import logging

from django.core.management import BaseCommand
from django.db import transaction
from isc_common.logger.Logger import Logger
from tqdm import tqdm

from kaf_pas.kd.models.cdws import Cdws
from kaf_pas.kd.models.documents import Documents
from kaf_pas.kd.models.documents_ext import DocumentManagerExt

logger = logging.getLogger(__name__)
logger.__class__ = Logger


class Command(BaseCommand):
    help = "Test Make CDW"
    documentManagerExt = DocumentManagerExt(logger=logger)

    def handle(self, *args, **options):
        cdws = [cdw for cdw in Cdws.objects.filter(props=~Documents.props.beenItemed) if cdw.file_document.lower().find('мусор') == -1]

        with transaction.atomic():
            pbar = tqdm(total=len(cdws))
            for document in cdws:
                self.documentManagerExt.make_cdw(document=document)
                pbar.update()
        pbar.close()



# Generated by Django 2.2.8 on 2019-12-14 14:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0102_auto_20191214_1433'),
    ]

    operations = [
        migrations.AlterField(
            model_name='lotsman_documents_hierarcy',
            name='id_lotsman',
            field=models.BigIntegerField(db_index=True),
        ),
    ]



# Generated by Django 2.2.1 on 2019-05-29 11:48

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0032_auto_20190529_1112'),
    ]

    operations = [
        migrations.AddField(
            model_name='operations',
            name='end',
            field=models.DateTimeField(blank=True, db_index=True, default=None),
        ),
        migrations.AddField(
            model_name='operations',
            name='start',
            field=models.DateTimeField(blank=True, db_index=True, default=None),
        ),
    ]



# Generated by Django 2.2.6 on 2019-10-29 07:10

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0102_auto_20191028_2134'),
    ]

    operations = [
        migrations.RenameField(
            model_name='precent',
            old_name='precent_type',
            new_name='precent_item_type',
        ),
    ]



from django.urls import path

from kaf_pas.planing.views import routing

urlpatterns = [

    path('Routing/Fetch/', routing.Routing_Fetch),
    path('Routing/Fetch1/', routing.Operations_FetchView),
    path('Routing/Add', routing.Routing_Add),
    path('Routing/Update', routing.Routing_Update),
    path('Routing/Remove', routing.Routing_Remove),
    path('Routing/Lookup/', routing.Routing_Lookup),
    path('Routing/Info/', routing.Routing_Info),
    path('Routing/Copy', routing.Routing_Copy),
    path('Routing/FetchLevels/', routing.Routing_FetchLevels),
    path('Routing/FetchLocationsLevel/', routing.Routing_FetchLocationsLevel),
    path('Routing/FetchResourcesLevel/', routing.Routing_FetchResourcesLevel),

]



# Generated by Django 2.2.6 on 2019-10-23 10:25

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0086_auto_20191022_2224'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='demand',
            name='due_date',
        ),
    ]



import logging

from django.contrib.postgres.fields import JSONField
from django.db.models import TextField

from isc_common.fields.related import ForeignKeyProtect, ForeignKeyCascade
from isc_common.models.audit import AuditModel, AuditManager, AuditQuerySet
from kaf_pas.ckk.models.item import Item
from kaf_pas.planing.models.operations import Operations

logger = logging.getLogger(__name__)


class Operation_itemQuerySet(AuditQuerySet):
    pass


class Operation_itemManager(AuditManager):

    @staticmethod
    def getRecord(record):
        res = {
            'id': record.id,
            'editing': record.editing,
            'deliting': record.deliting,
        }
        return res

    def get_queryset(self):
        return Operation_itemQuerySet(self.model, using=self._db)


class Operation_item(AuditModel):
    operation = ForeignKeyCascade(Operations)
    item = ForeignKeyProtect(Item)
    item_full_name = TextField()
    item_full_name_obj = JSONField(default=dict)

    objects = Operation_itemManager()

    def __str__(self):
        return f"ID:{self.id}, operation: [{self.operation}], item: [{self.item}], item_full_name: {self.item_full_name}, item_full_name_obj: {self.item_full_name_obj}"

    def __repr__(self):
        return self.__str__()

    class Meta:
        verbose_name = 'Кросс таблица'
        unique_together = (('operation', 'item'),)



import logging

from django.core.management import BaseCommand
from django.db import connection, transaction
from tqdm import tqdm

from kaf_pas.production.models.launch_operation_resources import Launch_operation_resources
from kaf_pas.production.models.operation_def_resources import Operation_def_resources
from kaf_pas.production.models.operation_resources import Operation_resources
from kaf_pas.production.models.resource import Resource
from kaf_pas.production.models.resource_users import Resource_users

logger = logging.getLogger(__name__)


class Command(BaseCommand):
    help = "Удаление дубликатов товарных позиций"

    def handle(self, *args, **options):
        with transaction.atomic():
            with connection.cursor() as cursor:
                cursor.execute(f'''select count(*), location_id, calendar_id
                                    from production_resource
                                    group by location_id, calendar_id
                                    having count(*) > 1
                                        ''')
                rows = cursor.fetchall()
                pbar = tqdm(total=len(rows))
                for row in rows:
                    count, location_id, calendar_id = row

                    first_step = True
                    _resource = None

                    for resource in Resource.objects.filter(location_id=location_id, calendar_id=calendar_id):
                        if not first_step:
                            for operation_resources in Operation_resources.objects.filter(resource=resource):
                                operation_resources.resource = _resource
                                operation_resources.save()

                            for operation_resources in Operation_def_resources.objects.filter(resource=resource):
                                operation_resources.resource = _resource
                                operation_resources.save()

                            for operation_resources in Launch_operation_resources.objects.filter(resource=resource):
                                operation_resources.resource = _resource
                                operation_resources.save()

                            for operation_resources in Resource_users.objects.filter(resource=resource):
                                operation_resources.resource = _resource
                                operation_resources.save()

                            resource.delete()
                        else:
                            _resource = resource
                            first_step = False
                    pbar.update()
                pbar.close()



import logging

from django.db.models import BigIntegerField, BooleanField, PositiveIntegerField
from django.forms import model_to_dict

from isc_common import setAttr
from isc_common.datetime import DateToStr
from isc_common.fields.code_field import CodeField
from isc_common.fields.name_field import NameField
from isc_common.fields.related import ForeignKeyProtect
from isc_common.http.DSRequest import DSRequest
from isc_common.models.audit import AuditQuerySet, AuditManager
from isc_common.models.base_ref import Hierarcy
from isc_common.number import DelProps
from kaf_pas.ckk.models.item import Item_add
from kaf_pas.ckk.models.item_line import Item_lineManager
from kaf_pas.ckk.models.item_refs import Item_refsManager, Item_refs
from kaf_pas.kd.models.document_attributes import Document_attributes
from kaf_pas.kd.models.documents import Documents

logger = logging.getLogger(__name__)


class Item_operations_viewQuerySet(AuditQuerySet):
    def raw(self, raw_query, params=None, translations=None, using=None, function=None):
        queryResult = super().raw(raw_query=raw_query, params=params, translations=translations, using=using)
        if function:
            res = [function(record) for record in queryResult]
            return res
        else:
            res = [model_to_dict(record) for record in queryResult]
            return res


class Item_operations_viewManager(AuditManager):
    def updateFromRequest(self, request, removed=None, function=None):
        if not isinstance(request, DSRequest):
            request = DSRequest(request=request)

        data = request.get_data()
        refs_id = data.get('refs_id')
        refs_props = data.get('refs_props')
        if data.get('used') == True:
            refs_props |= Item_refs.props.used
        else:
            refs_props &= ~Item_refs.props.used

        refs_data = dict()
        setAttr(refs_data, 'props', refs_props)

        Item_refs.objects.update_or_create(id=refs_id, defaults=refs_data)

        return data

    @staticmethod
    def getRecord(record):
        res = {
            'id': record.id,
            'refs_id': record.refs_id,
            'STMP_1_id': record.STMP_1.id if record.STMP_1 else None,
            'STMP_1__value_str': record.STMP_1.value_str if record.STMP_1 else None,
            'STMP_2_id': record.STMP_2.id if record.STMP_2 else None,
            'STMP_2__value_str': record.STMP_2.value_str if record.STMP_2 else None,
            'lastmodified': DateToStr(record.lastmodified, mask='%Y-%m-%dT%H:%M:%S'),
            'document_id': record.document.id if record.document else None,
            'document__file_document': record.document.file_document if record.document else None,
            'parent_id': record.parent_id,
            'editing': record.editing,
            'deliting': record.deliting,
            'isFolder': record.isFolder,
            'relevant': record.relevant,
            'confirmed': record.confirmed,
            'version': record.version,
            'section': record.section,
            'where_from': record.where_from,
            'qty_operations': record.qty_operations,
            'icon': Item_lineManager.getIcon(record),
            'props': record.props,
            'used': record.refs_props.used,
            'refs_props': record.refs_props,
        }
        # print(res)
        return DelProps(res)

    def get_queryset(self):
        return Item_operations_viewQuerySet(self.model, using=self._db)


class Item_operations_view(Hierarcy):
    STMP_1 = ForeignKeyProtect(Document_attributes, verbose_name='Наименование изделия', related_name='STMP_1_view_operations', null=True, blank=True)
    STMP_2 = ForeignKeyProtect(Document_attributes, verbose_name='Обозначение изделия', related_name='STMP_2_view_operations', null=True, blank=True)
    document = ForeignKeyProtect(Documents, verbose_name='Документ', null=True, blank=True)
    refs_id = BigIntegerField()
    relevant = NameField()
    confirmed = NameField()
    where_from = NameField()
    props = Item_add.get_prop_field()
    refs_props = Item_refsManager.props()
    version = PositiveIntegerField(null=True, blank=True)
    qty_operations = PositiveIntegerField()
    section = CodeField(null=True, blank=True)

    isFolder = BooleanField()

    objects = Item_operations_viewManager()

    @property
    def item(self):
        from kaf_pas.ckk.models.item import Item
        return Item.objects.get(id=self.id)

    def __str__(self):
        return f'ID={self.id} STMP_1=[{self.STMP_1}], STMP_2=[{self.STMP_2}], props={self.props}'

    class Meta:
        managed = False
        db_table = 'ckk_item_operations_view'
        verbose_name = 'Товарная позиция'



from django.urls import path

from kaf_pas.planing.views import status_operation_types

urlpatterns = [

    path('Status_operation_types/Fetch/', status_operation_types.Status_operation_types_Fetch),
    path('Status_operation_types/Add', status_operation_types.Status_operation_types_Add),
    path('Status_operation_types/Update', status_operation_types.Status_operation_types_Update),
    path('Status_operation_types/Remove', status_operation_types.Status_operation_types_Remove),
    path('Status_operation_types/Lookup/', status_operation_types.Status_operation_types_Lookup),
    path('Status_operation_types/Info/', status_operation_types.Status_operation_types_Info),
    path('Status_operation_types/Copy', status_operation_types.Status_operation_types_Copy),

]



# Generated by Django 2.2.6 on 2019-10-14 09:42

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0155_item_operations_view'),
    ]

    operations = [
        migrations.AlterModelTable(
            name='item_operations_view',
            table='ckk_item_operations_view',
        ),
    ]



from django.urls import path

from kaf_pas.production.views import ready_2_launch

urlpatterns = [

    path('Ready_2_launch/Fetch/', ready_2_launch.Ready_2_launch_Fetch),
    path('Ready_2_launch/Add', ready_2_launch.Ready_2_launch_Add),
    path('Ready_2_launch/Update', ready_2_launch.Ready_2_launch_Update),
    path('Ready_2_launch/Remove', ready_2_launch.Ready_2_launch_Remove),
    path('Ready_2_launch/Lookup/', ready_2_launch.Ready_2_launch_Lookup),
    path('Ready_2_launch/Info/', ready_2_launch.Ready_2_launch_Info),
    path('Ready_2_launch/Copy', ready_2_launch.Ready_2_launch_Copy),

]



import logging

from kaf_pas.kd.models.documents import Documents, DocumentManager, DocumentQuerySet

logger = logging.getLogger(__name__)


class Lotsman_documentsQuerySet(DocumentQuerySet):
    pass


class Lotsman_documentsManager(DocumentManager):
    def get_queryset(self):
        return Lotsman_documentsQuerySet(self.model, using=self._db).filter(attr_type__code='LOTSMAN')


class Lotsman_documents(Documents):
    objects = Lotsman_documentsManager()

    class Meta:
        verbose_name = 'Докумеенты Лоцман'
        proxy = True



from django.urls import path

from kaf_pas.production.views import operations_template_detail

urlpatterns = [

    path('Operations_template_detail/Fetch/', operations_template_detail.Operations_template_detail_Fetch),
    path('Operations_template_detail/Add', operations_template_detail.Operations_template_detail_Add),
    path('Operations_template_detail/Update', operations_template_detail.Operations_template_detail_Update),
    path('Operations_template_detail/Remove', operations_template_detail.Operations_template_detail_Remove),
    path('Operations_template_detail/Lookup/', operations_template_detail.Operations_template_detail_Lookup),
    path('Operations_template_detail/Info/', operations_template_detail.Operations_template_detail_Info),
    path('Operations_template_detail/Copy', operations_template_detail.Operations_template_detail_Copy),
    path('Operations_template_detail/CopyOpers2Template', operations_template_detail.Operations_template_detail_CopyOpers),

]



# Generated by Django 2.2.6 on 2019-10-22 22:07

import django.db.models.deletion
from django.db import migrations

import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0079_auto_20191022_1242'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='precent_materials',
            options={'verbose_name': 'Комплектация'},
        ),
        migrations.RemoveField(
            model_name='demand',
            name='document',
        ),
        migrations.RemoveField(
            model_name='demand',
            name='item',
        ),
        migrations.RemoveField(
            model_name='demand',
            name='precent',
        ),
        migrations.AddField(
            model_name='demand',
            name='precent_dogovor',
            field=isc_common.fields.related.ForeignKeyProtect(default=None, on_delete=django.db.models.deletion.PROTECT, to='sales.Precent_dogovors'),
        ),
        migrations.AddField(
            model_name='demand',
            name='precent_item',
            field=isc_common.fields.related.ForeignKeyProtect(default=None, on_delete=django.db.models.deletion.PROTECT, to='sales.Precent_items'),
        ),
        migrations.AlterField(
            model_name='demand',
            name='status',
            field=isc_common.fields.related.ForeignKeyProtect(default=None, on_delete=django.db.models.deletion.PROTECT, to='sales.Status_demand'),
        ),
    ]



from django.urls import path

from kaf_pas.kd.models.download_file import download_attach_file, download_attach_file_10
from kaf_pas.kd.views import documents_thumb

urlpatterns = [

    path('DocumentsThumb/Fetch/', documents_thumb.Documents_thumb_Fetch),
    path('DocumentsThumb/Add', documents_thumb.Documents_thumb_Add),
    path('DocumentsThumb/Update', documents_thumb.Documents_thumb_Update),
    path('DocumentsThumb/Remove', documents_thumb.Documents_thumb_Remove),
    path('DocumentsThumb/Lookup/', documents_thumb.Documents_thumb_Lookup),
    path('DocumentsThumb/Info/', documents_thumb.Documents_thumb_Info),
    path('DocumentsThumb/Download/<int:id>/', download_attach_file),
    path('DocumentsThumb/Download10/<int:id>/', download_attach_file_10),
]



# Generated by Django 3.0.3 on 2020-02-16 21:06

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0186_auto_20200216_2013'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='ready_2_launch_detail',
            name='mat_view_name',
        ),
    ]



# Generated by Django 2.2.1 on 2019-05-29 06:28

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0067_auto_20190529_0628'),
    ]

    operations = [
        migrations.AlterField(
            model_name='item',
            name='document',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='kd.Documents', verbose_name='Документ'),
        ),
    ]



# Generated by Django 3.0.3 on 2020-02-22 16:08

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0108_auto_20200222_1030'),
    ]

    operations = [
        migrations.CreateModel(
            name='Production_order',
            fields=[
            ],
            options={
                'verbose_name': 'Оприходования',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('planing.operations_view',),
        ),
    ]



import logging

import requests
from django.conf import settings
from django.http import HttpResponseRedirect

logger = logging.getLogger(__name__)


def download_attach_file(request, id):
    ws_channel = request.session.get('ws_channel')
    ws_port = settings.WS_PORT
    ws_host = settings.WS_HOST

    r = requests.get(f'{settings.KOMPAS_INFORMICA}/logic/DocumentsThumb/Download/{id}/', params=dict(ws_port=ws_port, ws_channel=ws_channel, ws_host=ws_host))
    logger.debug(f'DocumentsThumb url: {r.url}')
    return HttpResponseRedirect(r.url)


def download_attach_file_10(request, id):
    ws_channel = request.session.get('ws_channel')
    ws_port = settings.WS_PORT
    ws_host = settings.WS_HOST

    r = requests.get(f'{settings.KOMPAS_INFORMICA}/logic/DocumentsThumb/Download10/{id}/', params=dict(ws_port=ws_port, ws_channel=ws_channel, ws_host=ws_host))
    logger.debug(f'DocumentsThumb10 url: {r.url}')
    return HttpResponseRedirect(r.url)



from django.urls import path

from kaf_pas.production.views import resource

urlpatterns = [

    path('Resource/Fetch/', resource.Resource_Fetch),
    path('Resource/Add', resource.Resource_Add),
    path('Resource/Update', resource.Resource_Update),
    path('Resource/Remove', resource.Resource_Remove),
    path('Resource/Lookup/', resource.Resource_Lookup),
    path('Resource/Info/', resource.Resource_Info),

]



from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ('input', '0001_initial'),
    ]
    atomic = True

    operations = [
        migrations.RunSQL(
            f"""insert into input_operation_plan_types(lastmodified , editing, deliting, code, name)
                                    values('NOW()', 'false' , 'false' ,'Manufacturing-Order', 'Заказы на продажу')"""
        ),
        migrations.RunSQL(
            f"""insert into input_operation_plan_types(lastmodified , editing, deliting, code, name)
                                        values('NOW()', 'false' , 'false' ,'Distribution-Order', 'Заказы на распределение')"""
        ),
        migrations.RunSQL(
            f"""insert into input_operation_plan_types(lastmodified , editing, deliting, code, name)
                                        values('NOW()', 'false' , 'false' ,'Purchase-Order', 'Заказы на закупку')"""
        ),
        migrations.RunSQL(
            f"""insert into input_operation_plan_types(lastmodified , editing, deliting, code, name)
                                        values('NOW()', 'false' , 'false' ,'Delivery-Order', 'Заказы на доставку')"""
        )
    ]



# Generated by Django 2.2.3 on 2019-07-31 17:05

from django.db import migrations
import isc_common.fields.code_field


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0136_auto_20190731_1632'),
    ]

    operations = [
        migrations.AddField(
            model_name='material_type',
            name='gost',
            field=isc_common.fields.code_field.CodeField(blank=True, null=True),
        ),
    ]



from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ('ckk', '0002_auto_20190327_0703'),
    ]
    atomic = True

    operations = [
        migrations.RunSQL(
            f"""insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'KD', 'КД', null , null, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified,deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'SPW', 'Спецификация', null, 1, 1)""",
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified,deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'CDW', 'Чертеж', null, 1, 1)""",
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified,deleted, editing , deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' ,'false' ,'SPC_CLM', 'Типы колонок', null, 2, 1)""",
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified,deleted, editing , deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'SPC_CLM_FORMAT','Формат',null ,4, 1)""",
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified,deleted, editing , deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false', 'false' ,'SPC_CLM_ZONE','Зона',null ,4, 1)""",
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified,deleted, editing , deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'SPC_CLM_POS','Позиция',null ,4, 1)""",
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified,deleted, editing , deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false', 'false' ,'SPC_CLM_MARK','Обозначение',null ,4, 1)""",
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified,deleted, editing , deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'SPC_CLM_NAME','Наименование',null ,4, 1)""",
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified,deleted, editing , deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false', 'false' ,'SPC_CLM_COUNT','Количество',null ,4, 1)""",
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified,deleted, editing , deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'SPC_CLM_NOTE','Примечание',null ,4, 1)""",
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified,deleted, editing , deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' , 'SPC_CLM_MASSA','Масса',null ,4, 1)""",
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified,deleted, editing , deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'SPC_CLM_MATERIAL','Материал',null ,4, 1)""",
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified,deleted, editing , deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'SPC_CLM_USER','Пользовательская',null ,4, 1)""",
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified,deleted, editing , deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'SPC_CLM_KOD','Код',null ,4, 1)""",
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified,deleted, editing , deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false', 'false' ,'SPC_CLM_FACTORY','Предприятие - изготовитель',null ,4, 1)""",
        ),
        # ----------------------------------------------------------Атрибуты основной надписи---------------------------------------------
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP', 'Атрибуты основной надписи',null,1, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_1', 'Наименование изделия' , '(в соответствии с требованиями ГОСТ 2.109—73), а также
наименование документа, если этому документу присвоен код. Для изделий народнохозяйственного
назначения допускается не указывать наименование документа, если его код определен ГОСТ
2.102-68, ГОСТ 2.601-95, ГОСТ 2.602-95, ГОСТ 2.701-84; ' , 17 , 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_2', 'Обозначение документа' , '(графу заполняют только на чертежах деталей);' , 17, 1 )"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_3', 'Обозначение материала детали' , '' , 17 , 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_4', 'Литера, присвоенная данному документу' , '(графу заполняют последовательно,
начиная с крайней левой клетки). Допускается в рабочей конструкторской документации литеру проставлять только в спецификациях
и технических условиях.
Для изделий, разрабатываемых по заказу Министерства обороны, перечень конструкторских
документов, на которых должна обязательно проставляться литера, согласуется с заказчиком (представителем
заказчика);' , 17 , 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_5', 'Масса изделия ' , 'по ГОСТ 2.109—73;' , 17 , 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_6', 'Масштаб' , '(проставляется в соответствии с ГОСТ 2.302—68 и ГОСТ 2.109—73); ' , 17 , 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_7', 'Порядковый номер листа' , '(на документах, состоящих из одного листа, графу не
заполняют);' , 17 , 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_8', 'Общее количество листов документа' , '(графу заполняют только на первом листе); ' , 17 , 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_9', 'Наименование или различительный индекс' , 'предприятия, выпускающего документ
(графу не заполняют, если различительный индекс содержится в обозначении документа);' , 17 , 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_10', 'Характер работы' , 'выполняемой лицом, подписывающим документ, в соответствии
с формами 1 и 2. Свободную строку заполняют по усмотрению разработчика, например:
«Начальник отдела», «Начальник лаборатории», «Рассчитал»;' , 17 , 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_110', 'Разраб.' , 'фамилия лица, подписавшего документ;' , 17 , 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_111', 'Пров.' , 'фамилия лица, подписавшего документ;' , 17 , 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_112', 'Т.контр.' , 'фамилия лица, подписавшего документ;' , 17 , 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_113', '10' , 'фамилия лица, подписавшего документ;' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_114', 'Н.контр.' , 'фамилия лица, подписавшего документ;' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_115', 'Утв.' , 'фамилия лица, подписавшего документ;' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_120', 'Разраб.' , 'подписи лиц, фамилии которых указаны в графе 11 (Подписи лиц, разработавших данный документ и ответственных за нормоконтроль, являются
обязательными.)' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_121', 'Пров.' , 'подписи лиц, фамилии которых указаны в графе 11' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_122', 'Т.контр.' , 'подписи лиц, фамилии которых указаны в графе 11' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_123', '10' , 'подписи лиц, фамилии которых указаны в графе 11' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_124', 'Н.контр.' , 'подписи лиц, фамилии которых указаны в графе 11 (Подписи лиц, разработавших данный документ и ответственных за нормоконтроль, являются
обязательными.)' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_125', 'Утв.' , 'подписи лиц, фамилии которых указаны в графе 11 (При отсутствии титульного листа допускается подпись лица, утвердившего документ, размещать
на свободном поле первого или заглавного листа документа в порядке, установленном для
титульных листов по ГОСТ 2.105—95.) Если необходимо на документе наличие визы должостных лиц, то их размещают на поле для
подшивки первого или заглавного листа документа; ' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_130', 'Дата подписания документа;' , '' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_131', 'Дата подписания документа;' , '' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_132', 'Дата подписания документа;' , '' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_133', 'Дата подписания документа;' , '' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_134', 'Дата подписания документа;' , '' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_135', 'Дата подписания документа;' , '' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_140', 'Изменения' , 'заполняют в соответствии с требованиями
ГОСТ 2.503—90;
' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_141', 'Изменения' , 'заполняют в соответствии с требованиями
ГОСТ 2.503—90;
' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_142', 'Изменения' , 'заполняют в соответствии с требованиями
ГОСТ 2.503—90;
' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_150', 'Изменения' , 'заполняют в соответствии с требованиями
ГОСТ 2.503—90;
' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_151', 'Изменения' , 'заполняют в соответствии с требованиями
ГОСТ 2.503—90;
' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_160', 'Изменения' , 'заполняют в соответствии с требованиями
ГОСТ 2.503—90;
' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_161', 'Изменения' , 'заполняют в соответствии с требованиями
ГОСТ 2.503—90;
' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_170', 'Изменения' , 'заполняют в соответствии с требованиями
ГОСТ 2.503—90;
' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_171', 'Изменения' , 'заполняют в соответствии с требованиями
ГОСТ 2.503—90;
' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_180', 'Изменения' , 'заполняют в соответствии с требованиями
ГОСТ 2.503—90;
' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_181', 'Изменения' , 'заполняют в соответствии с требованиями
ГОСТ 2.503—90;
' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_19', 'Инвентарный номер подлинника' , 'по ГОСТ 2.501—88;' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_200', 'Подпись' , 'лица, принявшего подлинник в отдел (бюро) технической документации,
и дату приемки;
' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_201', 'Дата' , 'подписания лицом, принявшего подлинник в отдел (бюро) технической документации,
и дату приемки;
' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_21', 'Инвентарный номер подлинника' , 'взамен которого выпущен данный подлинник
по ГОСТ 2.503-90;' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_22', 'Инвентарный номер дубликата' , 'по ГОСТ 2.502—68;' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_230', 'Подпись' , 'лица, принявшего дубликат в отдел (бюро) технической документации,
и дату приемки;' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_231', 'Дата' , 'подписания лицом, принявшего дубликат в отдел (бюро) технической документации,
и дату приемки;' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_24', 'Обозначение документа' , 'взамен или на основании которого выпущен данный
документ. Допускается также использовать графу для указания обозначения документа аналогичного
изделия, для которого ранее изготовлена технологическая оснастка, необходимая для данного
изделия;' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_25', 'Обозначение соответствующего документа' , 'в котором впервые записан данный
документ' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_26', 'Обозначение документа' , 'повернутое на 180° для формата А4 и для форматов
больше А4 при расположении основной надписи вдоль длинной стороны листа и на 90° для форматов
больше А4 при расположении основной надписи вдоль короткой стороны листа;' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_27', 'Знак, установленный заказчиком' , 'в соответствии с требованиями нормативнотехнической
документации и проставляемый представителем заказчика;' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_28', 'Номер решения и год утверждения' , 'документации соответствующей литеры; ' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_29', 'Номер решения и год утверждения' , 'документации' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_30', 'Индекс заказчика' , 'в соответствии с нормативно-технической документацией; ' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_31', 'Подпись' , 'лица, копировавшего чертеж;' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_32', 'Обозначение' , 'формата листа по ГОСТ 2.301—68;' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_33', 'Обозначение зоны' , 'в которой находится изменяемая часть изделия; ' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_34', 'Номера авторских свидетельств' , 'на изобретения, использованные в данном изделии.' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_43', 'Полное имя файла содержащего данный документ' , '' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_44', 'Краткое имя файла содержащего данный документ' , '' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_40', '...' , '' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_41', '...' , '' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_45', '...' , '' , 17, 1)"""
        ),
        migrations.RunSQL(
            """insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                    values('NOW()', 'false', 'false' , 'false' ,'STMP_53', '...' , '' , 17, 1)"""
        ),
        # ----------------------------------------------------------End Атрибуты основной надписи-----------------------------------------
        migrations.RunSQL(
            f"""insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                        values('NOW()', 'false', 'false' , 'false' ,'KD_BAD', 'Битая КД', null , null, 1)"""
        ),
        migrations.RunSQL(
            f"""insert into ckk_attr_type(lastmodified , deleted, editing, deliting, code, name, description ,parent_id, props)
                                            values('NOW()', 'false', 'false' , 'false' ,'KD_PDF', 'Бумажная КД', null , null, 1)"""
        ),
    ]



# Generated by Django 2.1.7 on 2019-03-27 11:41

import bitfield.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0002_auto_20190327_1111'),
    ]

    operations = [
        migrations.AddField(
            model_name='document_attrs',
            name='props',
            field=bitfield.models.BitField((('relevant', 'Актуальность'),), blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='documents',
            name='props',
            field=bitfield.models.BitField((('relevant', 'Актуальность'), ('beenItemed', 'Был внесен в состав изделий')), default=1),
        ),
    ]



# Generated by Django 2.2.7 on 2019-11-18 13:50

import bitfield.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0105_auto_20191118_1130'),
    ]

    operations = [
        migrations.AddField(
            model_name='launch_item_line',
            name='props',
            field=bitfield.models.BitField((('enabled', 'Доступность в данной производственной спецификации'),), db_index=True, default=0),
        ),
        migrations.AddField(
            model_name='launch_item_refs',
            name='props',
            field=bitfield.models.BitField((('enabled', 'Доступность в данной производственной спецификации'),), db_index=True, default=0),
        ),
        migrations.AddField(
            model_name='launch_operation_resources',
            name='props',
            field=bitfield.models.BitField((('enabled', 'Доступность в данной производственной спецификации'),), db_index=True, default=0),
        ),
        migrations.AddField(
            model_name='launch_operations_item',
            name='props',
            field=bitfield.models.BitField((('enabled', 'Доступность в данной производственной спецификации'),), db_index=True, default=0),
        ),
        migrations.AddField(
            model_name='launch_operations_material',
            name='props',
            field=bitfield.models.BitField((('enabled', 'Доступность в данной производственной спецификации'),), db_index=True, default=0),
        ),
    ]



import logging

from django.db.models import BooleanField

from clndr.models.calendars import Calendars
from isc_common.fields.related import ForeignKeyProtect
from isc_common.managers.common_managet_with_lookup_fields import CommonManagetWithLookUpFieldsQuerySet, CommonManagetWithLookUpFieldsManager
from isc_common.models.base_ref import BaseRefHierarcy, BaseRef
from isc_common.number import DelProps
from kaf_pas.ckk.models.locations import Locations
from kaf_pas.production.models.resource import ResourceManager

logger = logging.getLogger(__name__)


class Resource_viewQuerySet(CommonManagetWithLookUpFieldsQuerySet):
    def filter(self, *args, **kwargs):
        return super().filter(*args, **kwargs)


class Resource_viewManager(CommonManagetWithLookUpFieldsManager):

    @staticmethod
    def getRecord(record):
        res = {
            'id': record.id,
            'code': record.code,
            'name': record.name,
            'description': record.description,
            'isFolder': record.isFolder,
            'calendar_id': record.calendar.id if record.calendar else None,
            'calendar__full_name': record.calendar.full_name if record.calendar else None,
            # 'isWorkshop': record.props.isWorkshop,
            # 'props': record.props,
            'editing': record.editing,
            'deliting': record.deliting,
        }
        return DelProps(res)

    def get_queryset(self):
        return Resource_viewQuerySet(self.model, using=self._db)

    @property
    def full_name(self):
        return f'{self.location.full_name}/{super().full_name}'


class Resource_view(BaseRef):
    location = ForeignKeyProtect(Locations)
    calendar = ForeignKeyProtect(Calendars, null=True, blank=True)
    isFolder = BooleanField()
    # props = ResourceManager.props()

    objects = Resource_viewManager()

    def __str__(self):
        return f"{self.id}"

    class Meta:
        db_table = 'production_resource_view'
        managed = False
        verbose_name = 'Ресурсы'



from django.urls import path

from kaf_pas.planing.views import operation_operation

urlpatterns = [

    path('Operation_operation/Fetch/', operation_operation.Operation_operation_Fetch),
    path('Operation_operation/Add', operation_operation.Operation_operation_Add),
    path('Operation_operation/Update', operation_operation.Operation_operation_Update),
    path('Operation_operation/Remove', operation_operation.Operation_operation_Remove),
    path('Operation_operation/Lookup/', operation_operation.Operation_operation_Lookup),
    path('Operation_operation/Info/', operation_operation.Operation_operation_Info),
    path('Operation_operation/Copy', operation_operation.Operation_operation_Copy),

]



# Generated by Django 2.2.8 on 2019-12-08 08:59

from django.db import migrations

from kaf_pas.production.models.launch_operation_resources import Launch_operation_resourcesManager
from kaf_pas.production.models.operation_resources import Operation_resourcesManager


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0160_auto_20191208_0812'),
    ]

    operations = [
        migrations.RunPython(Launch_operation_resourcesManager.refresh_resource),
        migrations.RunPython(Operation_resourcesManager.refresh_resource),
    ]



# Generated by Django 3.0.3 on 2020-02-10 12:48

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0206_auto_20200209_1230'),
    ]

    operations = [
        migrations.RemoveConstraint(
            model_name='materials',
            name='Materials_unique_constraint_0',
        ),
        migrations.RemoveConstraint(
            model_name='materials',
            name='Materials_unique_constraint_1',
        ),
    ]



import logging

from bitfield import BitField
from django.db import transaction
from django.db.models import PositiveIntegerField
from django.forms import model_to_dict

from isc_common import delAttr, setAttr
from isc_common.bit import IsBitOn
from isc_common.fields.description_field import DescriptionField
from isc_common.fields.related import ForeignKeyProtect, ForeignKeySetNull
from isc_common.http.DSRequest import DSRequest
from isc_common.managers.common_managet_with_lookup_fields import CommonManagetWithLookUpFieldsQuerySet, CommonManagetWithLookUpFieldsManager
from isc_common.models.base_ref import Hierarcy
from isc_common.number import DelProps
from kaf_pas.ckk.models.ed_izm import Ed_izm
from kaf_pas.ckk.models.item import Item
from kaf_pas.production.models.launches import Launches
from kaf_pas.production.models.operations import Operations
from kaf_pas.production.models.operations_item import Operations_item

logger = logging.getLogger(__name__)


class Launch_operations_itemQuerySet(CommonManagetWithLookUpFieldsQuerySet):
    def filter(self, *args, **kwargs):
        return super().filter(*args, **kwargs)


class Launch_operations_itemManager(CommonManagetWithLookUpFieldsManager):

    @staticmethod
    def getRecord(record):
        res = {
            'id': record.id,
            'launch_id': record.launch.id,
            'operation_id': record.operation.id,
            'operationitem_id': record.operationitem.id if record.operationitem else None,
            'operation__code': record.operation.code,
            'operation__name': record.operation.name,
            'operation__full_name': record.operation.full_name,
            'operation__description': record.operation.description,
            'ed_izm_id': record.ed_izm.id if record.ed_izm else None,
            'ed_izm__code': record.ed_izm.code if record.ed_izm else None,
            'ed_izm__name': record.ed_izm.name if record.ed_izm else None,
            'ed_izm__description': record.ed_izm.description if record.ed_izm else None,
            'qty': record.qty,
            'num': record.num,
            'description': record.description,
            'item_id': record.item.id,
            'parent_id': record.parent.id if record.parent else None,
            'props': record.props._value,
            'enabled': IsBitOn(record.props, 0),
            'editing': record.editing,
            'deliting': record.deliting,
        }
        return res

    def get_queryset(self):
        return Launch_operations_itemQuerySet(self.model, using=self._db)

    def _rec_def_resources(self, launch_operationitem):
        from kaf_pas.production.models.operation_def_resources import Operation_def_resources
        from kaf_pas.production.models.launch_operation_resources import Launch_operation_resources

        for operation_def_resource in Operation_def_resources.objects.filter(operation=launch_operationitem.operation):
            Launch_operation_resources.objects.get_or_create(
                launch_operationitem=launch_operationitem,
                resource=operation_def_resource.resource,
                location=operation_def_resource.location,
            )

    def createFromRequest(self, request):
        request = DSRequest(request=request)
        data = request.get_data()
        _data = data.copy()
        delAttr(_data, 'operation__full_name')

        oparations = _data.get('operation')
        item_id = _data.get('item_id')
        delAttr(_data, 'operation')
        res = []
        if isinstance(oparations, list):
            with transaction.atomic():
                if isinstance(item_id, int):
                    for oparation in oparations:
                        setAttr(_data, 'operation_id', oparation)
                        _res, created = super().get_or_create(**_data)
                        if created:
                            self._rec_def_resources(_res)
                            res1 = model_to_dict(_res)
                            setAttr(res1, 'operation__full_name', _res.operation.full_name)
                            res.append(DelProps(res1))
                elif isinstance(item_id, list):
                    delAttr(_data, 'item_id')
                    for oparation in oparations:
                        for item in item_id:
                            setAttr(_data, 'operation_id', oparation)
                            setAttr(_data, 'item_id', item)
                            _res, created = super().get_or_create(**_data)
                            if created:
                                self._rec_def_resources(_res)
                                res1 = model_to_dict(_res)
                                setAttr(res1, 'operation__full_name', _res.operation.full_name)
                                res.append(DelProps(res1))

        return res

    def updateFromRequest(self, request, removed=None, function=None):
        request = DSRequest(request=request)
        data = request.get_data()
        _data = data.copy()

        delAttr(_data, 'operation__full_name')
        delAttr(_data, 'enabled')
        delAttr(_data, 'id')
        res = super().filter(id=data.get('id')).update(**_data)

        return data


class Launch_operations_item(Hierarcy):
    description = DescriptionField()
    ed_izm = ForeignKeyProtect(Ed_izm, null=True, blank=True)
    item = ForeignKeyProtect(Item)
    launch = ForeignKeyProtect(Launches)
    num = PositiveIntegerField(null=True, blank=True, db_index=True)
    operation = ForeignKeyProtect(Operations)
    operationitem = ForeignKeySetNull(Operations_item, null=True, blank=True)
    qty = PositiveIntegerField(null=True, blank=True, db_index=True)
    props = BitField(flags=(
        ('enabled', 'Доступность в данной производственной спецификации'),  # 1
    ), default=1, db_index=True)

    objects = Launch_operations_itemManager()

    def __str__(self):
        return f"ID:{self.id}, item: [{self.item}], id_izm: [{self.ed_izm}], qty: {self.qty}, num: {self.num}"

    def __repr__(self):
        return self.operation.full_name

    class Meta:
        verbose_name = 'Кросс таблица'
        unique_together = (('item', 'launch', 'operation'),)



import logging

from bitfield import BitField
from django.contrib.postgres.fields import JSONField
from django.db.models import CheckConstraint, Q, F, UniqueConstraint, TextField, DecimalField, FloatField

from isc_common.fields.related import ForeignKeyProtect, ForeignKeySetNull
from isc_common.models.audit import AuditModel, AuditManager, AuditQuerySet
from isc_common.models.tree_audit import TreeAuditModelManager
from isc_common.number import DelProps
from kaf_pas.ckk.models.item import Item
from kaf_pas.ckk.models.item_refs import Item_refs
from kaf_pas.production.models.launches import Launches

logger = logging.getLogger(__name__)


class Launch_item_refsQuerySet(AuditQuerySet):
    pass


class Launch_item_refsManager(AuditManager):

    @staticmethod
    def props():
        return BitField(flags=(
            ('enabled', 'Доступность в данной производственной спецификации'),  # 1
        ), default=1, db_index=True)

    @staticmethod
    def getRecord(record):
        res = {
            'id': record.id,
            'props': record.props._value,
            'enabled': record.props.enabled,
            'editing': record.editing,
            'deliting': record.deliting,
        }
        return DelProps(res)

    def get_queryset(self):
        return Launch_item_refsQuerySet(self.model, using=self._db)


class Launch_item_refs(AuditModel):
    child = ForeignKeyProtect(Item, related_name='launch_child')
    item_refs = ForeignKeySetNull(Item_refs, blank=True, null=True)
    launch = ForeignKeyProtect(Launches)
    parent = ForeignKeyProtect(Item, related_name='launch_parent', blank=True, null=True)
    props = Launch_item_refsManager.props()
    item_full_name = TextField()
    item_full_name_obj = JSONField(default=dict)
    qty = FloatField()
    qty_per_one = FloatField()

    objects = Launch_item_refsManager()
    tree_objects = TreeAuditModelManager()

    def __str__(self):
        return f"ID: {self.id}, " \
               f"qty: {self.qty}, " \
               f"qty_per_one: {self.qty_per_one}, " \
               f"child: [{self.child}], " \
               f"parent: [{self.parent}], " \
               f"item_refs: [{self.item_refs}], " \
               f"launch: [{self.launch}], " \
               f"props: {self.props}"

    def __repr__(self):
        return self.__str__()

    class Meta:
        verbose_name = 'Древо производственной спецификации'
        constraints = [
            CheckConstraint(check=~Q(child=F('parent')), name='Launch_item_refs_not_circulate_refs'),
            UniqueConstraint(fields=['child', 'launch'], condition=Q(parent=None), name='Launch_item_refs_unique_constraint_0'),
            UniqueConstraint(fields=['child', 'launch', 'parent'], name='Launch_item_refs_unique_constraint_1'),
        ]



# Generated by Django 2.2.1 on 2019-05-28 23:13

import bitfield.models
from django.db import migrations, models
import django.utils.timezone
import isc_common.fields.code_field


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0046_precent_item_line'),
    ]

    operations = [
        migrations.CreateModel(
            name='Precent_item_line_view',
            fields=[
                ('id', models.BigAutoField(primary_key=True, serialize=False, verbose_name='Идентификатор')),
                ('id_old', models.BigIntegerField(blank=True, null=True, verbose_name='Идентификатор старый')),
                ('deleted_at', models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата мягкого удаления')),
                ('editing', models.BooleanField(default=True, verbose_name='Возможность редактирования')),
                ('deliting', models.BooleanField(default=True, verbose_name='Возможность удаления')),
                ('lastmodified', models.DateTimeField(db_index=True, default=django.utils.timezone.now, editable=False, verbose_name='Последнее обновление')),
                ('section', isc_common.fields.code_field.CodeField(blank=True, null=True, verbose_name='Раздел')),
                ('subsection', isc_common.fields.code_field.CodeField(blank=True, null=True, verbose_name='Подраздел')),
                ('isFolder', models.BooleanField(default=False, verbose_name='Признак наличия потомков')),
                ('used', models.BooleanField(default=False, verbose_name='Признак используемости запуске')),
                ('props', bitfield.models.BitField((('relevant', 'Актуальность'),), default=1)),
            ],
            options={
                'verbose_name': 'Строка спецификации запуска',
                'db_table': 'ckk_item_line_mview',
                'ordering': ['section'],
                'managed': False,
            },
        ),
    ]



import logging

from django.db.models import EmailField

from isc_common.fields.code_field import CodeField
from isc_common.fields.name_field import NameField
from isc_common.models.audit import AuditQuerySet, AuditManager, AuditModel

logger = logging.getLogger(__name__)


class User_agg_viewQuerySet(AuditQuerySet):
    def filter(self, *args, **kwargs):
        return super().filter(*args, **kwargs)


class User_agg_viewManager(AuditManager):

    @staticmethod
    def getRecord(record):
        res = {
            'id': record.id,
            'username': record.username,
            'first_name': record.first_name,
            'last_name': record.last_name,
            'email': record.email,
            'middle_name': record.middle_name,
            'location_position': record.location_position,
        }
        return res

    def get_queryset(self):
        return User_agg_viewQuerySet(self.model, using=self._db)


class User_agg_view(AuditModel):
    username = CodeField()
    first_name = NameField()
    last_name = NameField()
    email = EmailField(blank=True, null=True)
    middle_name = NameField()
    location_position = NameField()

    objects = User_agg_viewManager()

    def __str__(self):
        return f"ID: {self.id} username {self.username}"

    class Meta:
        verbose_name = 'Пользователи'
        db_table = 'user_agg_view'
        managed = False



# Generated by Django 3.0.3 on 2020-02-08 07:35

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0194_auto_20200208_0735'),
    ]

    operations = [
        migrations.RemoveConstraint(
            model_name='item',
            name='unique_with_optional',
        ),
    ]



# Generated by Django 2.2.8 on 2019-12-04 20:13

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0163_locations_users'),
        ('production', '0143_operations_item_q_paralel'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='operations_item',
            unique_together={('item', 'num', 'operation')},
        ),
    ]



import logging

from django.conf import settings
from django.db.models import Sum

from isc_common.number import DelProps
from kaf_pas.planing.models.operations import OperationsManager, OperationsQuerySet
from kaf_pas.planing.models.operations_view import Operations_view

logger = logging.getLogger(__name__)


class Production_order_detailQuerySet(OperationsQuerySet):
    pass


class Production_order_detailManager(OperationsManager):
    @staticmethod
    def getRecord(record):
        res = {
            'id': record.id,
            'num': record.id,
            'date': record.date,
            'prev_status_id': record.prev_status.id if record.prev_status else None,
            'production_operation__full_name': record.production_operation.full_name if record.production_operation else None,
            'production_operation__name': record.production_operation.name if record.production_operation else None,
            'production_operation_edizm__name': record.production_operation_edizm.name if record.production_operation_edizm else None,
            'production_operation_edizm_id': record.production_operation_edizm.id if record.production_operation_edizm else None,
            'production_operation_id': record.production_operation.id if record.production_operation else None,
            'production_operation_num': record.production_operation_num,
            'production_operation_qty': record.production_operation_qty,
            'production_operation_attrs': record.production_operation.attrs if record.production_operation else None,
            'launch_id': record.launch.id if record.launch else None,
            'location__code': record.resource.location.code if record.resource and record.resource else None,
            'location__full_name': record.resource.location.full_name if record.resource and record.resource else None,
            'location__name': record.resource.location.name if record.resource and record.resource else None,
            'location_id': record.resource.location.id if record.resource else None,
            'resource__code': record.resource.code if record.resource and record.resource else None,
            'resource__name': record.resource.name if record.resource and record.resource else None,
            'resource__description': record.resource.description if record.resource and record.resource else None,
            'resource_id': record.resource.id if record.resource else None,
            'value': record.value.value if record.value else None,
            'value_start': record.value_start,
            'value_made': record.value_made,
            'description': record.description,
            'edizm__code': record.value.edizm.code if record.value and record.value.edizm else None,
            'edizm__name': record.value.edizm.name if record.value and record.value.edizm else None,
            'edizm_id': record.value.edizm.id if record.value and record.value.edizm else None,
        }
        return DelProps(res)

    def get_queryset(self):
        return Production_order_detailQuerySet(self.model, using=self._db)


class Production_order_detail(Operations_view):
    @property
    def get_status(self):
        return self.status

    @property
    def value_start(self):
        from kaf_pas.planing.models.operation_refs import Operation_refs
        try:
            res = Operation_refs.objects.get(child_id=self.id, parent__opertype__code='PRD_TSK')
            value_start = res.parent.value_start
            return value_start
        except Operation_refs.DoesNotExist:
            return 0

    @property
    def value_made(self):
        from kaf_pas.planing.models.operation_refs import Operation_refs
        from kaf_pas.planing.models.operation_value import Operation_value

        operations = [child.child_id for child in Operation_refs.objects.filter(parent_id=self.id, child__opertype=settings.OPERS_TYPES_STACK.MADE_OPERATIONS_TASK)]
        res = Operation_value.objects.filter(operation_id__in=operations).aggregate(Sum('value'))
        sum = res.get('value__sum')
        return sum if sum != None else 0

    @property
    def value_per_one(self):
        from kaf_pas.planing.models.operation_value import Operation_value
        try:
            return Operation_value.objects.get(operation_id=self.id, props=Operation_value.props.perone).value
        except Operation_value.DoesNotExist:
            return 0


    def __str__(self):
        return super().__str__()

    def __repr__(self):
        return self.__str__()

    class Meta:
        proxy = True
        verbose_name = 'Заказы на производство'



import logging

from django.db import transaction
from django.db.models import PositiveIntegerField, DateTimeField

from isc_common import delAttr, setAttr
from isc_common.fields.related import ForeignKeyProtect, ForeignKeyCascade
from isc_common.http.DSRequest import DSRequest
from isc_common.managers.common_managet_with_lookup_fields import CommonManagetWithLookUpFieldsManager, CommonManagetWithLookUpFieldsQuerySet
from isc_common.models.base_ref import BaseRefHierarcy
from kaf_pas.sales.models.precent import Precent
from kaf_pas.sales.models.precent_dogovors import Precent_dogovors
from kaf_pas.sales.models.precent_items import Precent_items
from kaf_pas.sales.models.precent_items_view import Precent_items_view
from kaf_pas.sales.models.status_demand import Status_demand

logger = logging.getLogger(__name__)


class DemandQuerySet(CommonManagetWithLookUpFieldsQuerySet):
    pass


class DemandManager(CommonManagetWithLookUpFieldsManager):

    @staticmethod
    def getRecord(record):
        res = {
            'id': record.id,
            'code': record.code,
            'name': record.name,
            'description': record.description,
            'parent': record.parent.id if record.parent else None,
            'date': record.date,
            'date_sign': record.precent.date_sign,
            'qty': record.qty,
            'parent_id': record.parent.id if record.parent else None,

            'precent_id': record.precent.id,
            'precent__code': record.precent.code,
            'precent__date': record.precent.date,

            'precent__precent_type_id': record.precent.precent_type.id,
            'precent__precent_type__name': record.precent.precent_type.name,

            'precent_dogovor_id': record.precent_dogovor.id,
            'precent_dogovor__code': record.precent_dogovor.dogovor.code,
            'precent_dogovor__name': record.precent_dogovor.dogovor.name,
            'precent_dogovor__date': record.precent_dogovor.dogovor.date,

            'precent_dogovor__dogovor__customer__name': record.precent_dogovor.dogovor.customer.name,

            'precent_item_id': record.precent_item.id,
            'precent_item__STMP_1_id': record.precent_item.item.STMP_1.id if record.precent_item.item.STMP_1 else None,
            'precent_item__STMP_1__value_str': record.precent_item.item.STMP_1.value_str if record.precent_item.item.STMP_1 else None,
            'precent_item__STMP_2_id': record.precent_item.item.STMP_2.id if record.precent_item.item.STMP_2 else None,
            'precent_item__STMP_2__value_str': record.precent_item.item.STMP_2.value_str if record.precent_item.item.STMP_2 else None,

            'status_id': record.status.id,
            'status__code': record.status.code,
            'status__name': record.status.name,
            'editing': record.editing,
            'deliting': record.deliting,
        }
        return res

    def get_queryset(self):
        return DemandQuerySet(self.model, using=self._db)

    def createFromRequest(self, request):
        from kaf_pas.sales.models.demand_materials import Demand_materials

        request = DSRequest(request=request)
        data = request.get_data()
        _data = data.copy()

        precent = _data.get('precent')
        if precent:
            with transaction.atomic():
                precent_id = precent.get('precent_id')
                setAttr(_data, 'precent_id', precent_id)
                precent_dogovor_id = precent.get('precent_dogovor_id')
                setAttr(_data, 'precent_dogovor_id', precent_dogovor_id)
                precent_item_id = precent.get('precent_item_id')
                setAttr(_data, 'precent_item_id', precent_item_id)
                delAttr(_data, 'precent')
                _qty = _data.get('qty')

                for precent_item in Precent_items.objects.filter(id=precent_item_id).select_for_update():
                    precent_item = Precent_items_view.objects.get(id=precent_item.id)
                    qty = precent_item.qty - precent_item.used_qty
                    if _qty > qty:
                        raise Exception(f'Нет затребованного количества. В наличии {qty}, затребовано: {_qty}')
                    res = super().create(**_data)
                    setAttr(_data, 'id', res.id)

                    precent_material_ids = precent.get('precent_material_ids')
                    if isinstance(precent_material_ids, list):
                        for precent_material_id in precent_material_ids:
                            Demand_materials.objects.get_or_create(demand=res, precent_material_id=precent_material_id)

        return _data

    def updateFromRequest(self, request, removed=None, function=None):
        request = DSRequest(request=request)
        data = request.get_data()

        _data = data.copy()
        with transaction.atomic():
            for precent_item in Precent_items.objects.filter(id=data.get('precent_item_id')).select_for_update():
                qty = Precent_items_view.objects.get(id=precent_item.id).qty
                if data.get('qty') > qty:
                    raise Exception(f'Нет затребованного количества. В наличии {qty}, затребовано: {data.get("qty")}')
            delAttr(_data, 'date_sign')
            super().filter(id=data.get('id')).update(**_data)

        return data


class Demand(BaseRefHierarcy):
    date = DateTimeField()
    precent = ForeignKeyCascade(Precent)
    precent_dogovor = ForeignKeyCascade(Precent_dogovors)
    precent_item = ForeignKeyCascade(Precent_items)
    status = ForeignKeyProtect(Status_demand)
    qty = PositiveIntegerField()

    objects = DemandManager()

    def __str__(self):
        return f"ID:{self.id}, " \
               f"code: {self.code}, " \
               f"name: {self.name}, " \
               f"description: {self.description}, " \
               f"status: [{self.status}], " \
               f"precent_item: [{self.precent_item}], " \
               f"precent_dogovor: [{self.precent_dogovor}], " \
               f"precent: [{self.precent}]"

    class Meta:
        verbose_name = 'Заказы на продажу'



# Generated by Django 2.2.1 on 2019-05-24 15:32

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0038_precent_materials'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='precent_materials',
            name='ed_izm',
        ),
    ]



# Generated by Django 2.2.1 on 2019-06-05 14:16

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0032_auto_20190530_1706'),
        ('ckk', '0070_auto_20190605_1415'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='item',
            unique_together={('STMP_1', 'STMP_2')},
        ),
    ]



# Generated by Django 2.2.7 on 2019-11-21 06:05

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0011_launch_item_refs_timing'),
    ]

    operations = [
        migrations.RenameField(
            model_name='launch_item_refs_timing',
            old_name='child',
            new_name='launch_item_refs',
        ),
    ]



# Generated by Django 2.2 on 2019-04-24 18:05

from django.db import migrations
import isc_common.fields.code_field


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0002_customer_parent'),
    ]

    operations = [
        migrations.AddField(
            model_name='customer',
            name='inn',
            field=isc_common.fields.code_field.CodeField(unique=True, verbose_name='ИНН'),
        ),
        migrations.AddField(
            model_name='customer',
            name='kpp',
            field=isc_common.fields.code_field.CodeField(blank=True, null=True, verbose_name='КПП'),
        ),
    ]



# Generated by Django 2.2.8 on 2019-12-12 17:45

from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0166_auto_20191212_1745'),
    ]

    operations = [
        migrations.AddField(
            model_name='item_refs_hierarcy',
            name='deleted_at',
            field=models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата мягкого удаления'),
        ),
        migrations.AddField(
            model_name='item_refs_hierarcy',
            name='deliting',
            field=models.BooleanField(default=True, verbose_name='Возможность удаления'),
        ),
        migrations.AddField(
            model_name='item_refs_hierarcy',
            name='editing',
            field=models.BooleanField(default=True, verbose_name='Возможность редактирования'),
        ),
        migrations.AddField(
            model_name='item_refs_hierarcy',
            name='lastmodified',
            field=models.DateTimeField(db_index=True, default=django.utils.timezone.now, editable=False, verbose_name='Последнее обновление'),
        ),
        migrations.AddField(
            model_name='item_refs_hierarcy',
            name='parent',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='ckk.Item_refs_hierarcy'),
        ),
    ]



from django.urls import path

from kaf_pas.input.views import user_positions

urlpatterns = [

    path('User_positions/Fetch/', user_positions.User_positions_Fetch),
    path('User_positions/Add', user_positions.User_positions_Add),
    path('User_positions/Update', user_positions.User_positions_Update),
    path('User_positions/Remove', user_positions.User_positions_Remove),
    path('User_positions/Lookup/', user_positions.User_positions_Lookup),
    path('User_positions/Info/', user_positions.User_positions_Info),

]



# Generated by Django 2.2 on 2019-04-19 05:36

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0021_documents_view'),
        ('ckk', '0033_auto_20190419_0023'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='item',
            unique_together={('STMP_1', 'STMP_2', 'props', 'document')},
        ),
    ]



# Generated by Django 2.2.6 on 2019-10-23 11:19

import django.utils.timezone
from django.db import migrations, models

import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0087_remove_demand_due_date'),
    ]

    operations = [
        migrations.CreateModel(
            name='Precent_items_view',
            fields=[
                ('id', models.BigAutoField(primary_key=True, serialize=False, verbose_name='Идентификатор')),
                ('deleted_at', models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата мягкого удаления')),
                ('editing', models.BooleanField(default=True, verbose_name='Возможность редактирования')),
                ('deliting', models.BooleanField(default=True, verbose_name='Возможность удаления')),
                ('lastmodified', models.DateTimeField(db_index=True, default=django.utils.timezone.now, editable=False, verbose_name='Последнее обновление')),
                ('qty', models.PositiveIntegerField()),
            ],
            options={
                'verbose_name': 'Комплектация распоряжения',
                'db_table': 'sales_precent_items_view',
                'managed': False,
            },
        ),
        migrations.AlterField(
            model_name='demand_materials',
            name='demand',
            field=isc_common.fields.related.ForeignKeyCascade(on_delete=django.db.models.deletion.CASCADE, to='sales.Demand'),
        ),
    ]



# Generated by Django 3.0.3 on 2020-02-12 07:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0139_auto_20200211_0902'),
    ]

    operations = [
        migrations.AddConstraint(
            model_name='pathes',
            constraint=models.UniqueConstraint(condition=models.Q(parent=None), fields=('id',), name='Pathes_unique_constraint_0'),
        ),
        migrations.AddConstraint(
            model_name='pathes',
            constraint=models.UniqueConstraint(fields=('id', 'parent'), name='Pathes_unique_constraint_1'),
        ),
    ]



from django.urls import path

from kaf_pas.sales.views import dogovors, precent

urlpatterns = [

    path('Dogovors/Fetch/', dogovors.Dogovors_Fetch),
    path('Dogovors/Add', dogovors.Dogovors_Add),
    path('Dogovors/Update', dogovors.Dogovors_Update),
    path('Dogovors/Remove', dogovors.Dogovors_Remove),
    path('Dogovors/Lookup/', dogovors.Dogovors_Lookup),
    path('Dogovors/Info/', dogovors.Dogovors_Info),
    path('Dogovors/Copy', dogovors.Dogovors_Copy),
    path('Dogovors/Upload', dogovors.Dogovor_UploadFile),
    path('Dogovors/Download/', dogovors.Dogovort_DownloadFile),
]



import logging

from django.conf import settings
from django.db import transaction
from django.forms import model_to_dict
from django.shortcuts import redirect

from isc_common import delAttr, setAttr, Stack
from isc_common.common.mat_views import create_tmp_table
from isc_common.http.DSRequest import DSRequest
from isc_common.http.DSResponse import DSResponseUpdate, DSResponseAdd, DSResponse, JsonResponseWithException, JsonWSResponseWithException
from isc_common.http.RPCResponse import RPCResponseConstant
from isc_common.http.response import JsonResponse
from kaf_pas.ckk.models.combineItems import CombineItems
from kaf_pas.ckk.models.copyItems import CopyItems
from kaf_pas.ckk.models.item import Item
from kaf_pas.ckk.models.item_line import Item_line
from kaf_pas.ckk.models.item_operations_view import Item_operations_view, Item_operations_viewManager
from kaf_pas.ckk.models.item_refs import Item_refs
from kaf_pas.ckk.models.item_view import Item_view, Item_viewManager
from kaf_pas.system.models.contants import Contants

logger = logging.getLogger(__name__)

item_top_level, _ = Contants.objects.update_or_create(code='top_level', defaults=dict(name='Вершины товарных позиций'))
audo_top_level = Contants.objects.update_or_create(code='audo_top_level', defaults=dict(parent=item_top_level, name='Автоматически сгененрированный состав изделий'))[0].value
typed_top_level = Contants.objects.update_or_create(code='typed_top_level', defaults=dict(parent=item_top_level, name='Типовые кузова'))[0].value
not_typed_top_level = Contants.objects.update_or_create(code='not_typed_top_level', defaults=dict(parent=item_top_level, name='Не типовые кузова'))[0].value
lotsman_top_level = Contants.objects.update_or_create(code='lotsman_top_level', defaults=dict(parent=item_top_level, name='Импорт из Лоцмана'))[0].value


def get_excl():
    excluded = []
    try:
        # excluded = [int(item.value) for item in Contants.objects.filter(code__in=['audo_top_level'])]
        excluded = []
    except:
        pass
    return excluded


def Item_view_query():
    # Item_view._meta.db_table = 'ckk_item_mview'
    query = Item_view.objects.exclude(id__in=get_excl())
    return query


@JsonResponseWithException()
def Item_view_Fetch(request):
    return JsonResponse(
        DSResponse(
            request=request,
            data=Item_view_query().
                get_range_rows1(
                request=request,
                function=Item_viewManager.getRecord,
                distinct_field_names=('id',)
            ),
            status=RPCResponseConstant.statusSuccess).response)


@JsonResponseWithException(printing=False)
def Item_view_Fetch1(request):
    return JsonResponse(
        DSResponse(
            request=request,
            data=Item_operations_view.objects.
                exclude(id__in=[int(item.value) for item in Contants.objects.filter(code__in=['audo_top_level'])]).
                get_range_rows1(request=request, function=Item_operations_viewManager.getRecord, distinct_field_names=('id',)),
            status=RPCResponseConstant.statusSuccess).response)


@JsonResponseWithException(printing=False)
def Item_view_Fetch2(request):
    from kaf_pas.production.models.ready_2_launch_detail import Ready_2_launch_detail

    _request = DSRequest(request=request)

    data = _request.get_data()

    with transaction.atomic():
        ready_2_launch_detail = Ready_2_launch_detail.objects.get(id=data.get('id'))
        tmp_table_name = f'ready_2_launch_detail_tmp_table'
        create_tmp_table(
            on_commit=None,
            drop=False,
            sql_str=f'''SELECT
                                       t."isFolder",
                                       t."STMP_1_id",
                                       t."STMP_2_id",
                                       t.deliting,
                                       t.document__file_document,
                                       t.document_id,
                                       t.editing,
                                       t.id,
                                       t.lastmodified,
                                       t.parent_id,
                                       t.props,
                                       t.qty_operations,
                                       t.refs_id,
                                       t.refs_props,
                                       t.relevant,
                                       t.section,
                                       t.version,
                                       t.where_from
                                FROM production_ready_2_launch_detail s
                                         CROSS JOIN LATERAL
                                    json_to_recordset(s.item_full_name_obj::json) as t(
                                                                                       "deliting" boolean,
                                                                                       "document__file_document" text,
                                                                                       "document_id" bigint,
                                                                                       "editing" boolean,
                                                                                       "id" bigint,
                                                                                       "isFolder" boolean,
                                                                                       "lastmodified" text,
                                                                                       "parent_id" bigint,
                                                                                       "props" bigint,
                                                                                       "qty_operations" int4,
                                                                                       "refs_id" bigint,
                                                                                       "refs_props" bigint,
                                                                                       "relevant" text,
                                                                                       "section" text,
                                                                                       "STMP_1_id" bigint,
                                                                                       "STMP_2_id" bigint,
                                                                                       "version" int4,
                                                                                       "where_from" text
                                                                                        )
                                    where s.id = %s''',
            params=[ready_2_launch_detail.id],
            table_name=tmp_table_name)

        return JsonResponse(
            DSResponse(
                request=request,
                data=Item_operations_view.objects.raw(
                    raw_query=f'select * from {tmp_table_name}',
                    function=Item_operations_viewManager.getRecord),
                status=RPCResponseConstant.statusSuccess).response)


class ItemRef:
    def __init__(self, item_ref):
        self.child = item_ref.child.id
        self.parent = item_ref.parent.id if item_ref.parent != None else item_ref.parent
        self.props = item_ref.props

    def __str__(self):
        return f'child: {self.child}, parent: {self.parent}, props: {self.props}'


class UploadTmpTable:
    cnt = 0
    cnt_fall = 0

    def __init__(self, data):
        self.id = data.get('id')
        self.lotsman_document_id = data.get('lotsman_document_id')
        self.stack = Stack()

    def _rec_item_ref(self, item_ref):
        from kaf_pas.ckk.models.tmp_item_refs import Tmp_Item_refs
        if len(self.stack.find(lambda x: x.child == item_ref.child.id and x.parent == (item_ref.parent.id if item_ref.parent else None) and x.props == item_ref.props)) == 0:
            Tmp_Item_refs.objects.create(child=item_ref.child, parent=item_ref.parent, props=item_ref.props)
            item = ItemRef(item_ref=item_ref)
            # print(f'Record Item ({self.stack.size() + 1}): {item}')
            self.stack.push(item)

    def _rec_perents(self, child, level):
        # print(f'level: {level}')
        for item_refs in Item_refs.objects.filter(child=child):
            self._rec_item_ref(item_ref=item_refs)
            if item_refs.parent != None:
                self._rec_perents(child=item_refs.parent, level=level + 1)
                # print(f'level: {level}')

    def make_tmp(self):
        from kaf_pas.kd.models.uploades_documents import Uploades_documents
        from kaf_pas.kd.models.lotsman_documents_hierarcy import Lotsman_documents_hierarcy
        from kaf_pas.ckk.models.item_document import Item_document

        for uploades_document in Uploades_documents.objects.filter(upload_id=self.id):
            for item in Item.objects.filter(document=uploades_document.document):
                self._rec_perents(child=item, level=1)
                for item_document in Item_document.objects.filter(document=uploades_document.document):
                    self._rec_perents(child=item_document.item, level=1)

            for lotsman_documents_hierarcy in Lotsman_documents_hierarcy.objects.filter(document=uploades_document.document):
                for item in Item.objects.filter(lotsman_document=lotsman_documents_hierarcy):
                    self._rec_perents(child=item, level=1)

        # print(f'Cnt: {Tmp_Item_operations_view.objects.count()}')


class UploadDocumentTmpTable(UploadTmpTable):
    def make_tmp(self):
        from kaf_pas.kd.models.lotsman_documents_hierarcy import Lotsman_documents_hierarcy
        from kaf_pas.ckk.models.item_document import Item_document

        if self.lotsman_document_id == None:
            for item in Item.objects.filter(document_id=self.id):
                self._rec_perents(child=item, level=1)

            for item_document in Item_document.objects.filter(document_id=self.id):
                self._rec_perents(child=item_document.item, level=1)

            for lotsman_documents_hierarcy in Lotsman_documents_hierarcy.objects.filter(document_id=self.id):
                for item in Item.objects.filter(lotsman_document=lotsman_documents_hierarcy):
                    self._rec_perents(child=item, level=1)
        else:
            for item in Item.objects.filter(lotsman_document_id=self.lotsman_document_id):
                self._rec_perents(child=item, level=1)

        # print(f'Cnt: {Tmp_Item_operations_view.objects.count()}')


@JsonResponseWithException(printing=False)
def Item_view_Fetch3(request):
    from kaf_pas.ckk.models.tmp_item_refs import Tmp_Item_refsManager
    from kaf_pas.ckk.models.tmp_item_operations_view import Tmp_Item_operations_viewManager

    _request = DSRequest(request=request)
    data = _request.get_data()

    if settings.LOCKS.locked(f'Item_view_Fetch3_{data.get("id")}'):
        redirect("http://ya.ru")
    settings.LOCKS.acquire(f'Item_view_Fetch3_{data.get("id")}')
    with transaction.atomic():
        Tmp_Item_refsManager.create()
        Tmp_Item_operations_viewManager.create()

        UploadTmpTable(data).make_tmp()

        settings.LOCKS.release(f'Item_view_Fetch3_{data.get("id")}')
        return JsonResponse(
            DSResponse(
                request=request,
                data=Item_operations_view.objects.raw(
                    raw_query=f'''select * from ckk_tmp_item_operations_view''',
                    function=Tmp_Item_operations_viewManager.getRecord
                ),
                status=RPCResponseConstant.statusSuccess).response)


@JsonResponseWithException(printing=False)
def Item_view_Fetch4(request):
    from kaf_pas.ckk.models.tmp_item_refs import Tmp_Item_refsManager
    from kaf_pas.ckk.models.tmp_item_operations_view import Tmp_Item_operations_viewManager

    _request = DSRequest(request=request)
    data = _request.get_data()

    if settings.LOCKS.locked(f'Item_view_Fetch4_{data.get("id")}'):
        redirect("http://ya.ru")
    settings.LOCKS.acquire(f'Item_view_Fetch4_{data.get("id")}')
    with transaction.atomic():
        Tmp_Item_refsManager.create()
        Tmp_Item_operations_viewManager.create()

        UploadDocumentTmpTable(data).make_tmp()

        settings.LOCKS.release(f'Item_view_Fetch4_{data.get("id")}')
        return JsonResponse(
            DSResponse(
                request=request,
                data=Item_operations_view.objects.raw(
                    raw_query=f'''select * from ckk_tmp_item_operations_view''',
                    function=Tmp_Item_operations_viewManager.getRecord
                ),
                status=RPCResponseConstant.statusSuccess).response)


@JsonResponseWithException()
def Item_view_Add(request):
    return JsonResponse(DSResponseAdd(data=Item.objects.createFromRequest(request=request), status=RPCResponseConstant.statusSuccess).response)


@JsonWSResponseWithException()
def Item_view_Update(request):
    return JsonResponse(DSResponseUpdate(data=Item.objects.updateFromRequest(request), status=RPCResponseConstant.statusSuccess).response)


@JsonResponseWithException()
def Item_view_Update1(request):
    return JsonResponse(DSResponseUpdate(data=Item_operations_view.objects.updateFromRequest(request), status=RPCResponseConstant.statusSuccess).response)


@JsonResponseWithException()
def Item_view_Remove(request):
    return JsonResponse(DSResponse(request=request, data=Item.objects.deleteFromRequest(request=request), status=RPCResponseConstant.statusSuccess).response)


@JsonResponseWithException()
def Item_view_Lookup(request):
    return JsonResponse(DSResponse(request=request, data=Item.objects.lookupFromRequest(request=request), status=RPCResponseConstant.statusSuccess).response)


@JsonResponseWithException()
def Item_view_Info(request):
    return JsonResponse(DSResponse(request=request, data=Item_view_query().get_info(request=request), status=RPCResponseConstant.statusSuccess).response)


@JsonResponseWithException()
def Item_view_Copy(request):
    return JsonResponse(DSResponse(request=request, data=Item_view.objects.copyFromRequest(request=request), status=RPCResponseConstant.statusSuccess).response)


@JsonResponseWithException(printing=False)
def copyItems(request):
    return JsonResponse(CopyItems(request).response)


@JsonResponseWithException(printing=False)
def combineItems(request):
    return JsonResponse(CombineItems(request).response)


@JsonResponseWithException()
def Item_view_CopyBlockItems(request):
    _request = DSRequest(request=request)
    source = _request.json.get('source')
    destination = _request.json.get('destination')

    if isinstance(source, dict) and isinstance(destination, dict):
        srecords = source.get('records')
        drecord = destination.get('record')

        if isinstance(srecords, list) and isinstance(drecord, dict):
            with transaction.atomic():
                for srecord in srecords:
                    item_refs, created = Item_refs.objects.get_or_create(parent_id=drecord.get('id'), child_id=srecord.get('child_id'))
                    item_line = Item_line.objects.get(id=srecord.get('id'))
                    dict_item_line = model_to_dict(item_line)
                    delAttr(dict_item_line, 'id')
                    setAttr(dict_item_line, 'parent_id', drecord.get('id'))
                    delAttr(dict_item_line, 'parent')
                    setAttr(dict_item_line, 'child_id', dict_item_line.get('child'))
                    delAttr(dict_item_line, 'child')

                    setAttr(dict_item_line, 'SPC_CLM_FORMAT_id', dict_item_line.get('SPC_CLM_FORMAT'))
                    delAttr(dict_item_line, 'SPC_CLM_FORMAT')
                    setAttr(dict_item_line, 'SPC_CLM_ZONE_id', dict_item_line.get('SPC_CLM_ZONE'))
                    delAttr(dict_item_line, 'SPC_CLM_ZONE')
                    setAttr(dict_item_line, 'SPC_CLM_POS_id', dict_item_line.get('SPC_CLM_POS'))
                    delAttr(dict_item_line, 'SPC_CLM_POS')
                    setAttr(dict_item_line, 'SPC_CLM_MARK_id', dict_item_line.get('SPC_CLM_MARK'))
                    delAttr(dict_item_line, 'SPC_CLM_MARK')
                    setAttr(dict_item_line, 'SPC_CLM_NAME_id', dict_item_line.get('SPC_CLM_NAME'))
                    delAttr(dict_item_line, 'SPC_CLM_NAME')
                    setAttr(dict_item_line, 'SPC_CLM_COUNT_id', dict_item_line.get('SPC_CLM_COUNT'))
                    delAttr(dict_item_line, 'SPC_CLM_COUNT')
                    setAttr(dict_item_line, 'SPC_CLM_NOTE_id', dict_item_line.get('SPC_CLM_NOTE'))
                    delAttr(dict_item_line, 'SPC_CLM_NOTE')
                    setAttr(dict_item_line, 'SPC_CLM_MASSA_id', dict_item_line.get('SPC_CLM_MASSA'))
                    delAttr(dict_item_line, 'SPC_CLM_MASSA')
                    setAttr(dict_item_line, 'SPC_CLM_MATERIAL_id', dict_item_line.get('SPC_CLM_MATERIAL'))
                    delAttr(dict_item_line, 'SPC_CLM_MATERIAL')
                    setAttr(dict_item_line, 'SPC_CLM_USER_id', dict_item_line.get('SPC_CLM_USER'))
                    delAttr(dict_item_line, 'SPC_CLM_USER')
                    setAttr(dict_item_line, 'SPC_CLM_KOD_id', dict_item_line.get('SPC_CLM_KOD'))
                    delAttr(dict_item_line, 'SPC_CLM_KOD')
                    setAttr(dict_item_line, 'SPC_CLM_FACTORY_id', dict_item_line.get('SPC_CLM_FACTORY'))
                    delAttr(dict_item_line, 'SPC_CLM_FACTORY')
                    parent_id = dict_item_line.get('parent_id')
                    delAttr(dict_item_line, 'parent_id')
                    child_id = dict_item_line.get('child_id')
                    delAttr(dict_item_line, 'child_id')
                    item_line, created = Item_line.objects.get_or_create(parent_id=parent_id, child_id=child_id, defaults=dict_item_line)

    return JsonResponse(DSResponse(request=request, status=RPCResponseConstant.statusSuccess).response)



# Generated by Django 2.2.4 on 2019-08-22 22:50

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('sales', '0051_remove_customer_full_name'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='customer',
            name='id_old',
        ),
        migrations.RemoveField(
            model_name='demand',
            name='id_old',
        ),
        migrations.RemoveField(
            model_name='precent',
            name='id_old',
        ),
        migrations.RemoveField(
            model_name='precent_item_line',
            name='id_old',
        ),
        migrations.RemoveField(
            model_name='precent_items',
            name='id_old',
        ),
        migrations.RemoveField(
            model_name='precent_materials',
            name='id_old',
        ),
    ]
